@@ -1,8 +1,15 @@
 <?php
+$lang['set_cachable'] = 'Zwischenspeicherung f&uuml;r dieses Template aktivieren';
+$lang['help_nocache'] = 'Die Zwischenspeicherung dieses Men&uuml;-Aufrufs deaktivieren. Wenn diesen Parameter auf irgend einen positiven Wert gesetzt wird, werden die Einstellungen im Content-Object und im Men&uuml;-Template &uuml;berschrieben.';
+$lang['cachable'] = 'Men&uuml; zwischenspeichern';
+$lang['help_childrenof'] = 'Mit dieser Option werden nur die Men&uuml;-Eintr&auml;ge angezeigt, die der Seite mit der ausgew&auml;hlten Seiten-ID oder dem Seiten-Alias untergeordnet sind.  Beispiel: <code>{menu childrenof=$page_alias}</code> zeigt nur die untergeordneten Seiten der aktuell angezeigten Seite.';
 $lang['usage'] = 'Verwendung';
-$lang['help_loadprops'] = 'Wenn Sie in Ihrem Men&uuml;Manager-Template die erweiterten M&ouml;glichkeiten nutzen m&ouml;chten, sollten Sie diesen Parameter verwenden. Ist dieser Parameter gesetzt, werden alle Content-Eigenschaften (wie zum Beispiel extra1, image, thumbnail usw.) jedes $node-Objekts geladen. Damit steigen zwar die Anzahl der Datenbankabfragen und der Speicherbedarf dramatisch an, aber es er&ouml;ffnen sich damit weitere M&ouml;glichkeiten f&uuml;r noch ausgefeiltere Men&uuml;s.';
+$lang['import'] = 'Importieren';
+$lang['edit'] = 'Bearbeiten';
+$lang['delete'] = 'L&ouml;schen';
+$lang['help_loadprops'] = 'Wenn Sie in Ihrem Men&uuml;Manager-Template die erweiterten M&ouml;glichkeiten NICHT einsetzen m&ouml;chten, k&ouml;nnen Sie diesen Parameter verwenden. Ist dieser Parameter gesetzt, werden verschiedene Content-Eigenschaften (wie zum Beispiel extra1, image, thumbnail usw.) des $node-Objekts NICHT geladen. Damit werden die Anzahl der Datenbankabfragen und der Speicherbedarf dramatisch reduziert, aber die M&ouml;glichkeiten f&uuml;r ausgefeilte Men&uuml;s gehen verloren.';
 $lang['readonly'] = 'Nur lesen';
-$lang['error_templatename'] = 'Sie k&ouml;nnen kein Template festlegen, dessen Name auf .tpl endet.';
+$lang['error_templatename'] = 'FEHLER: Die Namen f&uuml;r Template d&uuml;rfen nicht auf .tpl enden.';
 $lang['this_is_default'] = 'Voreingestelltes Men&uuml;-Template';
 $lang['set_as_default'] = 'Als voreingestelltes Men&uuml;-Template festlegen';
 $lang['default'] = 'Voreingestellt';
@@ -10,6 +17,8 @@ $lang['templates'] = 'Templates ';
 $lang['addtemplate'] = 'Template hinzuf&uuml;gen';
 $lang['areyousure'] = 'Wollen Sie dies wirklich l&ouml;schen?';
 $lang['changelog'] = '	<ul>
+<li>1.7 - Adds the possibility to cache menumanager output to a cache file, this will remove a bunch of queries from mostly static sites.</li>
+<li>1.6.3 - Adds usage column.</li>
 <li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
 <li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
@@ -33,8 +42,8 @@ $lang['help_includeprefix'] = 'Mit diesem Parameter werden nur die Eintr&auml;ge
 $lang['help_excludeprefix'] = 'Mit diesem Parameter werden alle Eintr&auml;ge (und deren untergeordneten Seiten), die den festgelegten Prefix enthalten, von der Anzeige ausgeschlossen (durch Komma getrennt).  Dieser Parameter muss nicht in Verbindung mit dem Parameter includeprefix verwendet werden.';
 $lang['help_collapse'] = 'Setzen Sie diesen Wert auf 1, wenn untergeordnete Seiten erst nach einem Klick auf die &uuml;bergeordnete Seite angezeigt werden sollen.';
 $lang['help_items'] = 'Verwenden Sie diesen Eintrag, um eine Liste mit Seiten auszuw&auml;hlen, die dieses Men&uuml; anzeigen soll. Der Wert sollte eine Liste mit durch Kommata getrennten Seiten-Aliasen sein.';
-$lang['help_number_of_levels'] = 'Mit dieser Einstellung kann festgelegt werden, bis zu welcher Tiefe das Men&uuml; angezeigt wird (Hinweis: Beim Festlegen dieses Parameters ist zu beachten, dass die Z&auml;hlung der Ebenen IMMER bei der obersten Ebene beginnt, unabh&auml;ngig von anderen Parametern wie z.Bsp. start_level). ';
-$lang['help_show_all'] = 'Mit dieser Option k&ouml;nnen all die Men&uuml;-Eintr&auml;ge angezeigt werden, bei denen bei Erstellung/Bearbeitung der Seite in der Registerkarte &quot;Optionen&quot; die Einstellung &quot;Im Men&uuml; anzeigen&quot; deaktiviert wurde. Inaktive Seiten werden auch weiterhin nicht angezeigt.';
+$lang['help_number_of_levels'] = 'Mit dieser Einstellung kann festgelegt werden, bis zu welcher Tiefe das Men&uuml; angezeigt wird.';
+$lang['help_show_all'] = 'Mit dieser Option werden die Men&uuml;-Eintr&auml;ge angezeigt, bei denen die Einstellung &quot;Seite im Men&uuml; anzeigen&quot; deaktiviert wurde. Inaktive Seiten werden auch weiterhin nicht angezeigt.';
 $lang['help_show_root_siblings'] = 'Diese Option ist nur n&uuml;tzlich, wenn ein Startelement (Parameter start_element) oder eine Startseite (Parameter start_page) vorgegeben werden. Es werden dann alle Eintr&auml;ge angezeigt, die die gleiche Ebene wie die ausgew&auml;hlte Startseite bzw. das ausgew&auml;hlte Startelement haben.';
 $lang['help_start_level'] = 'Mit dieser Option zeigt das Men&uuml; nur Eintr&auml;ge ab einer vorgegebenen Ebene an. Stellen Sie sich folgendes Beispiel vor: Sie m&ouml;chten im Hauptmen&uuml; nur eine Ebene anzeigen. Der Parameter daf&uuml;r ist number_of_levels=&#039;1&#039;. In einem zweiten Men&uuml; sollen nur die untergeordneten Seiten des jeweiligen Eintrages aus der ersten Ebene angezeigt werden. Der Parameter daf&uuml;r ist start_level=&#039;2&#039;.';
 $lang['help_start_element'] = 'Beginnt die Men&uuml;-Anzeige ab einem festgelegten Startelement und zeigt nur das Element und dessen untergeordneten Seiten an. Verwendet die hierarchische Position (z.B. 5.1.2).';
@@ -70,12 +79,12 @@ $lang['help'] = '	<h3>Was macht das Modul?</h3>
 			<li>$node->menutext -- Men&uuml;text</li>
 			<li>$node->raw_menutext -- Men&uuml;text ohne Konvertierung der HTML-Entit&auml;ten</li>
                         <li>$node->alias -- Seiten-Alias</li>
-                        <li>$node->extra1 -- Zus&auml;tzliches Seiten-Attribut 1. Steht nur zur Verf&uuml;gung, wenn der Men&uuml;Manager mit dem Parameter loadprops aufgerufen wurde.</li>
-                        <li>$node->extra2 -- Zus&auml;tzliches Seiten-Attribut 2. Steht nur zur Verf&uuml;gung, wenn der Men&uuml;Manager mit dem Parameter loadprops aufgerufen wurde.</li>
-                        <li>$node->extra3 -- Zus&auml;tzliches Seiten-Attribut 3. Steht nur zur Verf&uuml;gung, wenn der Men&uuml;Manager mit dem Parameter loadprops aufgerufen wurde.</li>
-                        <li>$node->image -- Bild f&uuml;r einen grafischen Link, falls definiert. Steht nur zur Verf&uuml;gung, wenn der Men&uuml;Manager mit dem Parameter loadprops aufgerufen wurde.</li>
-                        <li>$node->thumbnail -- Vorschaubild f&uuml;r einen grafischen Link, falls definiert. Steht nur zur Verf&uuml;gung, wenn der Men&uuml;Manager mit dem Parameter loadprops aufgerufen wurde.</li>
-			<li>$node->target -- Ziel f&uuml;r den Link. Ist leer, wenn bei den Einstellungen des Inhalts nichts gesetzt wurde. Steht nur zur Verf&uuml;gung, wenn der Men&uuml;Manager mit dem Parameter loadprops aufgerufen wurde.</li>
+                        <li>$node->extra1 -- Dieses Feld enth&auml;lt das zus&auml;tzliches Seiten-Attribut 1, au&szlig;er der Men&uuml;Manager wurde &uuml;ber den Parameter loadprops so konfiguriert, diese Eigenschaft NICHT zu laden.</li>
+                        <li>$node->extra2 -- Dieses Feld enth&auml;lt das zus&auml;tzliches Seiten-Attribut 2, au&szlig;er der Men&uuml;Manager wurde &uuml;ber den Parameter loadprops so konfiguriert, diese Eigenschaft NICHT zu laden.</li>
+                        <li>$node->extra3 -- Dieses Feld enth&auml;lt das zus&auml;tzliches Seiten-Attribut 3, au&szlig;er der Men&uuml;Manager wurde &uuml;ber den Parameter loadprops so konfiguriert, diese Eigenschaft NICHT zu laden.</li>
+                        <li>$node->image -- Dieses Feld enth&auml;lt den Wert f&uuml;r ein Bild eines grafischen Links (falls definiert), au&szlig;er der Men&uuml;Manager wurde &uuml;ber den Parameter loadprops so konfiguriert, diese Eigenschaft NICHT zu laden.</li>
+                        <li>$node->thumbnail -- Dieses Feld enth&auml;lt den Wert f&uuml;r ein Vorschaubild eines grafischen Links (falls definiert), au&szlig;er der Men&uuml;Manager wurde &uuml;ber den Parameter loadprops so konfiguriert, diese Eigenschaft NICHT zu laden.</li>
+			<li>$node->target -- Dieses Feld enth&auml;lt das Ziel f&uuml;r den Link (falls definiert), au&szlig;er der Men&uuml;Manager wurde &uuml;ber den Parameter loadprops so konfiguriert, diese Eigenschaft NICHT zu laden.</li>
 			<li>$node->created -- Datum der Erstellung des Nodes</li>
 			<li>$node->modified -- Datum der letzten &Auml;nderung des Nodes</li>
 			<li>$node->index -- Z&auml;hler dieses Nodes im gesamten Men&uuml;</li>
@@ -83,18 +92,22 @@ $lang['help'] = '	<h3>Was macht das Modul?</h3>
 			<li>$node->current -- gibt true zur&uuml;ck, wenn der Node die aktuell ausgew&auml;hlte Seite ist</li>
 			<li>$node->type -- Inhaltstyp des Nodes. M&ouml;gliche Werte sind content (=Inhalt), errorpage (=Fehlerseite), link (=externer Link), pagelink (=interner Seitenlink), sectionheader (=Abschnitts&uuml;berschrift) sowie separator (=Trenner).</li>
 		</ul>
-	</p>';
+	</p>
+        <h3>Zwischenspeicherung</h3>
+        <p>Dieses Modul hat die M&ouml;glichkeit, die Ausgabe in statischen Dateien zu speichern, um die Speicheranforderungen sowie die erforderlichen Datenbankabfragen zu reduzieren, und damit die Performance der Webseite zu erh&ouml;hen. Dies bietet alle Vorteile der statischen Men&uuml;s ohne die Unannehmlichkeiten beim Erstellen oder Bearbeiten von Seiten.</p>
+        <p>So kann jedes Men&uuml;-Template &uuml;ber einen Klick in der Spalte &quot;Men&uuml; zwischenspeichern&quot; zwischengespeichert werden. Wenn ein Men&uuml;-Template mit Zwischenspeicherung auf einer Inhaltsseite verwendet wird, die ebenfalls zwischengespeichert wird, werden alle f&uuml;r diese Seite verf&uuml;gbaren Men&uuml;-Ausgaben verwendet. Mit dem Parameter nocache im menu-Tag kann die Zwischenspeicherung vollst&auml;ndig deaktiviert werden.</p>
+        <p>Alle zwischengespeicherten Men&uuml;-Dateien werden gel&ouml;scht, wenn Inhalte hinzugef&uuml;gt, bearbeitet oder gel&ouml;scht werden ... und nat&uuml;rlich auch dann, wenn ein Men&uuml;-Template hinzugef&uuml;gt, bearbeitet oder gel&ouml;scht wird.</p>';
 $lang['importtemplate'] = 'Template in die Datenbank importieren';
 $lang['menumanager'] = 'Men&uuml;Manager';
 $lang['newtemplate'] = 'Neuer Template-Name';
 $lang['nocontent'] = 'Es wurde kein Inhalt vorgegeben.';
-$lang['notemplatefiles'] = 'Keine Template-Datei in %s';
+$lang['notemplatefiles'] = 'Keine Template-Dateien in %s vorhanden';
 $lang['notemplatename'] = 'Es wurde kein Template-Name vergeben.';
 $lang['templatecontent'] = 'Template-Inhalt';
 $lang['templatenameexists'] = 'Ein Template mit diesem Namen existiert bereits.';
-$lang['qca'] = 'P0-75091478-1268421814072';
-$lang['utmz'] = '156861353.1272379137.12.8.utmcsr=cmsmadesimple.de|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.728989452.1268567475.1271758833.1272379137.12';
+$lang['qca'] = 'P0-1458450664-1284573084918';
+$lang['utma'] = '156861353.1471831631.1316290999.1316290999.1316290999.1';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272379137';
+$lang['utmz'] = '156861353.1316290999.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
