@@ -1,6 +1,13 @@
 <?php
+$lang['set_cachable'] = 'Gabarit activ&eacute; comme cachable';
+$lang['help_nocache'] = 'D&eacute;sactivez tout cache pour cet appel au menu. Ce param&egrave;tre, s&#039;il est r&eacute;gl&eacute; &agrave; une valeur positive remplace tous les param&egrave;tres dans l&#039;objet contenu et le gabarit de menu.';
+$lang['cachable'] = 'Cachable ';
+$lang['help_childrenof'] = 'Cette option affichera le menu uniquement des &eacute;l&eacute;ments qui sont descendants de l&#039;ID de la page s&eacute;lectionn&eacute;e ou de l&#039;alias. par exemple : <code>{menu childrenof=$page_alias}</code> affichera uniquement les enfants de la page courante.';
 $lang['usage'] = 'Balise pour utiliser le menu';
-$lang['help_loadprops'] = 'Utiliser ce param&egrave;tre si des propri&eacute;t&eacute;s avanc&eacute;es sont utilis&eacute;es dans votre gabarit de gestionnaire de menu. Ce param&egrave;tre va forcer le chargement des toutes les propri&eacute;t&eacute;s des contenus de tous les n&oelig;uds (tel que extra1, image, thumbnail, etc). Ceci va augmenter tr&egrave;s fortement le nombre de requ&ecirc;tes pour construire un menu ainsi que la consommation en m&eacute;moire, mais permet de g&eacute;rer des menus plus avanc&eacute;s';
+$lang['import'] = 'Importer';
+$lang['edit'] = 'Editer';
+$lang['delete'] = 'Supprimer';
+$lang['help_loadprops'] = 'Utiliser ce param&egrave;tre lorsque vous n&#039;utilisez PAS les propri&eacute;t&eacute;s avanc&eacute;es  dans votre gabarit de gestionnaire de menu. Ce param&egrave;tre permet de d&eacute;sactiver le chargement de toutes les propri&eacute;t&eacute;s des contenus de tous les n&oelig;uds (tel que extra1, image, thumbnail, etc). Cette op&eacute;ration r&eacute;duira consid&eacute;rablement le nombre de requ&ecirc;tes n&eacute;cessaires &agrave; la construction d&#039;un menu en contrepartie la consommation en m&eacute;moire augmente, mais cela permet de g&eacute;rer des menus plus avanc&eacute;s.';
 $lang['readonly'] = 'lecture seule';
 $lang['error_templatename'] = 'Vous ne pouvez pas sp&eacute;cifier un nom de gabarit qui se terminent par. tpl';
 $lang['this_is_default'] = 'Gabarit menu par d&eacute;faut ';
@@ -10,6 +17,7 @@ $lang['templates'] = 'Gabarits';
 $lang['addtemplate'] = 'Ajouter un gabarit';
 $lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer&nbsp;?';
 $lang['changelog'] = '	<ul>
+<li>1.7 - Adds the possibility to cache menumanager output to a cache file, this will remove a bunch of queries from mostly static sites. Fixes to childrenof parameter.</li>
 <li>1.6.3 - Adds usage column.</li>
 <li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
@@ -18,7 +26,7 @@ $lang['changelog'] = '	<ul>
         <li>1.5.3 - Support for syntax hilighter.</li>
         <li>1.5.2 - Added more fields available in each node in the template.</li>
 <li>1.5 - Changement de version pour &ecirc;tre compatible avec la 1.1 seulement, et ajout du SetParameterTypes</li>
-	<li>1.4.1 - Corrige un probleme sur le menu si includeprefix n&#039;est pas sp&eacute;cifi&eacute;.
+	<li>1.4.1 - Corrige un probl&egrave;me sur le menu si includeprefix n&#039;est pas sp&eacute;cifi&eacute;.</li>
 	<li>1.4 - Accepte la virgule comme s&eacute;parateur de liste pour includeprefixes ou excludeprefixes</li>
 	<li>1.3 - Ajout param&egrave;tres includeprefix et excludeprefix </li>
 	<li>1.1 - Ajout du support de l&#039;attribut target, principalement pour le type de contenu &quot;lien&quot;</li> 
@@ -47,42 +55,52 @@ $lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
 	<p>Ins&eacute;rez simplement la balise dans votre gabarit/page: <code>{menu}</code>.  Les param&egrave;tres possibles sont list&eacute;s plus bas.</p>
 	<h3>Pourquoi m&#039;occuper de gabarits?</h3>
 	<p>Le module Gestion de Menus utilise des gabarits pour son affichage. Il est install&eacute; avec 3 gabarits par d&eacute;faut, nomm&eacute;s cssmenu.tpl, minimal_menu.tpl et simple_navigation.tpl. Tous cr&eacute;ent une simple liste de pages, en utilisant diff&eacute;rentes classes et ID, afin de pouvoir leur donner un style gr&acirc;ce au CSS</p>
-	<p>Notez bien que vous pouvez donner un style &agrave; vos menus par l&#039;interm&eacute;diaire du CSS. Les feuilles de style ne sont pas incluses au module Gestion de Menus, mais doivent &ecirc;tre attach&eacute;es au gabarit de pages s&eacute;par&eacute;ment. Pour que le gabarit cssmenu.tpl fonctionne sous Internet Explorer, vous devez &eacute;galement, dans la partie en-t&ecirc;te de votre gabarit de page, ins&eacute;rer un lien au JavaScript qui permet l&#039;affichage de l&#039;effet survolage dans le navigateur Internet Explorer.</p>
+	<p>Notez bien que vous pouvez donner un style &agrave; vos menus par l&#039;interm&eacute;diaire du CSS. Les feuilles de style ne sont pas incluses au module Gestion de Menus, mais doivent &ecirc;tre attach&eacute;es au gabarit de pages s&eacute;par&eacute;ment. Pour que le gabarit cssmenu.tpl fonctionne sous Internet Explorer, vous devez &eacute;galement, dans la partie en-t&ecirc;te de votre gabarit de page, ins&eacute;rer un lien au JavaScript qui permet l&#039;affichage de l&#039;effet survol dans le navigateur Internet Explorer.</p>
 	<p>Si vous d&eacute;sirez cr&eacute;er une version personnalis&eacute;e d&#039;un gabarit de menu, vous pouvez facilement l&#039;importer dans la base de donn&eacute;es, puis l&#039;&eacute;diter directement dans le panneau d&#039;administration de CMSMS.  Proc&eacute;der ainsi&nbsp;:</p>
 		<ol>
 			<li>Cliquez sur l&#039;administration de Gestion de Menus.</li>
-			<li>Cliquez sur l&#039;onglet &#039;Gabarits sous forme de fichiers&#039;, et cliquez  &#039;Importer le gabarit dans la base de donn&eacute;es&#039; &agrave; c&ocirc;t&eacute; de simple_navigation.tpl, par exemple.</li>
-			<li>Donnez un nouveau nom &agrave; ce gabarit. Nous l&#039;appelerons &quot;gabarit test&quot;</li>
+			<li>Cliquez sur l&rsquo;ic&ocirc;ne &quot;Importer le gabarit dans la base de donn&eacute;es&quot; &agrave; droite, par exemple sur la ligne simple_navigation.tpl,</li>
+			<li>Donnez un nouveau nom &agrave; ce gabarit. Nous l&rsquo;appellerons &quot;gabarit_test&quot;</li>
 			<li>Vous devriez maintenant voir &quot;gabarit test&quot; dans la liste &#039;Gabarits se trouvant dans la base de donn&eacute;es&#039;.</li>
 		</ol>
 	
-	<p>Maintenant, vous pouvez ais&eacute;ment modifier le gabarit pour le modifier &agrave; votre convenance pour le site. Ins&eacute;rez des classes, des ID et d&#039;autres balises afin que le format g&eacute;n&eacute;r&eacute; soit exactement celui que vous d&eacute;sirez. Puis, ins&eacute;rez votre menu dans le site avec&nbsp;: {menu template=&#039;gabarit test&#039;}. Notez que l&#039;extension .tpl extension doit &ecirc;tre ajout&eacute;e dans le cas d&#039;une utilisation d&#039;un gabarit sour forme de fichier.</p>
+	<p>Maintenant, vous pouvez ais&eacute;ment modifier le gabarit pour le modifier &agrave; votre convenance pour le site. Ins&eacute;rez des classes, des ID et d&#039;autres balises afin que le format g&eacute;n&eacute;r&eacute; soit exactement celui que vous d&eacute;sirez. Puis, ins&eacute;rez votre menu dans le site avec&nbsp;: {menu template=&#039;gabarit test&#039;}. Notez que l&#039;extension .tpl extension doit &ecirc;tre ajout&eacute;e dans le cas d&#039;une utilisation d&#039;un gabarit sous forme de fichier.</p>
 	<p>Les param&egrave;tres pour l&#039;&eacute;l&eacute;ment $node utilis&eacute;s dans un gabarit sont les suivants&nbsp;:</p>
 		<ul>
 			<li>$node->id -- ID de l&#039;&eacute;l&eacute;ment</li>
 			<li>$node->url -- URL de l&#039;&eacute;l&eacute;ment</li>
 			<li>$node->accesskey -- Access Key, si d&eacute;finie</li>
 			<li>$node->tabindex -- Tab Index, si d&eacute;fini</li>
-			<li>$node->titleattribute -- Attribut titre, s d&eacute;fini</li>
+			<li>$node->titleattribute -- Description ou attribut titre, si d&eacute;fini</li>
 			<li>$node->hierarchy -- Position hi&eacute;rarchique (exemple : 1.3.3)</li>
 			<li>$node->depth -- Niveau de cet &eacute;l&eacute;ment dans le menu actuel</li>
 			<li>$node->prevdepth -- Niveau de l&#039;&eacute;l&eacute;ment juste avant l&#039;&eacute;l&eacute;ment actuel</li>
 			<li>$node->haschildren -- Renvoie true (vrai) si cet &eacute;l&eacute;ment a des niveaux &quot;enfants&quot; qui doivent &ecirc;tre affich&eacute;s.</li>
+<li>$node->children_exist -- Renvoie true (vrai) si l&#039;&eacute;l&eacute;ment poss&egrave;de des &eacute;l&eacute;ments enfants disponibles dans la base de donn&eacute;es qui peuvent &ecirc;tre affich&eacute;s dans le menu</li>
 			<li>$node->menutext -- Texte du menu</li>
+<li>$node->pagetitle -- Titre de la page</li>
 <li>$node->raw_menutext -- Texte du menu sans convertir les entit&eacute;s html</li>
 			<li>$node->alias -- Alias de la page</li>
 
-			<li>$node->extra1 -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page extra1.</li>
-			<li>$node->extra2 -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page extra2.</li>
-			<li>$node->extra3 -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page extra3.</li>
-			<li>$node->image -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page de l&#039;image(si non vide).</li>
-			<li>$node->thumbnail -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page de la vignette del&#039;image(si non vide).</li>
-			<li>$node->target -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la cible du lien. Sera vide si le contenu n&#039;est pas d&eacute;fini.</li>
+			<li>$node->extra1 -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page extra1, sauf si le param&egrave;tre loadprops, contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+
+			<li>$node->extra2 -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page extra2, sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+
+			<li>$node->extra3 -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page extra3, sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+
+			<li>$node->image -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page de l&#039;image(si non vide), sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+			<li>$node->thumbnail -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page de la vignette de l&#039;image(si non vide), sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+			<li>$node->target -- Cette zone contient la cible du lien (si non vide), sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
 
 			<li>$node->index -- Position de cet &eacute;l&eacute;ment dans le menu</li>
 			<li>$node->parent -- Renvoie true (vrai) si cet &eacute;l&eacute;ment est le parent de la page actuelle</li>
+<li>$node->current -- Renvoie true (vrai) si cet &eacute;l&eacute;ment  est la page s&eacute;lectionn&eacute;e</li>
 		</ul>
-	';
+
+<h3>Mise en cache</h3>
+<p>Ce module a la capacit&eacute; de mettre en cache sa sortie dans des fichiers statiques pour r&eacute;duire les besoins en m&eacute;moire et des requ&ecirc;tes SQL, et pour am&eacute;liorer les performances du site Web. Cela offre tous les avantages des menus statiques sans les inconv&eacute;nients impliqu&eacute;s lors de la cr&eacute;ation ou la modification des pages.</p>
+<p>Chaque gabarit de menu peut &ecirc;tre marqu&eacute; comme &quot;&ecirc;tre mis en cache&quot;. Quand un mod&egrave;le de menu cachable est utilis&eacute;e sur une page de contenu qui est mis en cache, toute sortie de menu en cache qui est disponible pour cette page sera utilis&eacute;s. Le param&egrave;tre nocache sur l&#039;&eacute;tiquette de menu peut &ecirc;tre utilis&eacute; pour d&eacute;sactiver compl&egrave;tement la mise en cache.</p>
+<p>Tous les fichiers mis en cache menu sont effac&eacute;s si un &eacute;l&eacute;ment de contenu est ajout&eacute;, modifi&eacute; ou supprim&eacute; ... et aussi quand un gabarit de menu est ajout&eacute;/modifi&eacute; ou supprim&eacute;.</p>	';
 $lang['importtemplate'] = 'Importer le gabarit dans la base de donn&eacute;es';
 $lang['menumanager'] = 'Gestion de Menu';
 $lang['newtemplate'] = 'Nom du nouveau gabarit&nbsp;';
@@ -91,9 +109,8 @@ $lang['notemplatefiles'] = 'Aucun gabarit sous forme de fichier dans %s';
 $lang['notemplatename'] = 'Aucun nom de gabarit entr&eacute;';
 $lang['templatecontent'] = 'Contenu du gabarit&nbsp;';
 $lang['templatenameexists'] = 'Un gabarit du m&ecirc;me nom existe d&eacute;j&agrave;';
-$lang['qca'] = 'P0-1624099198-1262715852421';
-$lang['utmz'] = '156861353.1272265461.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utma'] = '156861353.1817163714.1272265461.1272265461.1272269036.2';
+$lang['utma'] = '156861353.1919860752.1316704117.1316704117.1316704117.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1316704117.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
