@@ -1,5 +1,12 @@
 <?php
+$lang['set_cachable'] = 'Dit sjabloon kan gebufferd worden.';
+$lang['help_nocache'] = 'Stel het bufferen van bestanden uit als u deze menu aanroep gebruikt. Deze parameter zal, als deze een positieve waarde heeft de instellingen van de Content en de Menu sjabloon negeren.';
+$lang['cachable'] = 'Bufferen';
+$lang['help_childrenof'] = 'Deze optie laat alleen onderliggende pagina&#039;s zijn van de gespecificeerde pagina id of alias. Bijv.: <code>{menu childrenof=$page_alias}</code> zal alleen de onderliggende pagina&#039;s tonen van de huidige pagina.';
 $lang['usage'] = 'Gebruik';
+$lang['import'] = 'Importeer';
+$lang['edit'] = 'Wijzig';
+$lang['delete'] = 'Verwijder';
 $lang['help_loadprops'] = 'Gebruik deze parameter wanneer u geavanceerde eigenschappen in uw menu manager gebruikt. Deze parameter zal het laden van alle inhoudstypen forceren voor elke node (zoals extra1, image, thumbnail, enz.) en zal het aantal queries om het menu te maken drastisch verlagen, waardoor het geheugengebruik veel lager wordt.';
 $lang['readonly'] = 'Alleen lezen';
 $lang['error_templatename'] = 'U kunt geen sjabloon maken met een .tpl extentie!';
@@ -10,7 +17,8 @@ $lang['templates'] = 'Sjablonen';
 $lang['addtemplate'] = 'Sjabloon toevoegen';
 $lang['areyousure'] = 'Weet u zeker dat u dit wilt verwijderen?';
 $lang['changelog'] = '<ul>
-<li>1.6.3 - Adds usage column. </li>
+<li>1.7 - Adds the possibility to cache menumanager output to a cache file, this will remove a bunch of queries from mostly static sites. </li>
+<li>1.6.3 - Adds usage column.</li>
 <li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
 <li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
@@ -51,13 +59,13 @@ $lang['help'] = '	<h3>Wat doet het?</h3>
 	<p>Als u een speciale versie van een sjabloon wilt maken, kunt u deze in de database importeren en vervolgens aanpassen via het beheerpaneel in CMSMS. Dit gaat als volgt in zijn werk:
 		<ol>
 			<li>Klik op Opmaak -> Menu Manager in het beheerpaneel.</li>
-			<li>Klik vervolgens in het Bestandssjabloon-tabblad op de Importeerknop achter een bestaande bestandsnaam, bijvoorbeeld die achter simple_navigation.tpl.</li>
+			<li>Klik vervolgens op de Importeerknop achter een bestaande bestandsnaam, bijvoorbeeld die achter simple_navigation.tpl.</li>
 			<li>Geef de sjabloonkopie een naam, bijvoorbeeld &quot;Testsjabloon&quot;.</li>
 			<li>U moet nu de Testsjabloon in het lijstje met Database-sjablonen zien.</li>
 		</ol>
 	</p>
 	<p>Nu kunt u eenvoudig het sjabloon bewerken. Plaats er classes , id&#039;s en andere tags in om de gewenste stijl te krijgen. Hierna kunt u het invoegen in uw website met {menu template=&#039;Testsjabloon&#039;}. Merk op dat de .tpl extensie toegevoegd moet worden als een bestandssjabloon wordt gebruikt.</p>
-	<p>De parameters voor het $node object die in het sjabloon gebruikt worden zijn:
+	<p>The parameters for the $node object used in the template are as follows:
 		<ul>
 			<li>$node->id -- Content ID</li>
 			<li>$node->url -- URL of the Content</li>
@@ -68,22 +76,28 @@ $lang['help'] = '	<h3>Wat doet het?</h3>
 			<li>$node->depth -- Depth (level) of this node in the current menu</li>
 			<li>$node->prevdepth -- Depth (level) of the node that was right before this one</li>
 			<li>$node->haschildren -- Returns true if this node has child nodes to be displayed</li>
+			<li>$node->children_exist -- Returns true if this node has child nodes available in the database that can be displayed in the menu</li>
 			<li>$node->menutext -- Menu Text</li>
 			<li>$node->raw_menutext -- Menu Text without having html entities converted</li>
 			<li>$node->alias -- Page alias</li>
-			<li>$node->extra1 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra1 page property.</li>
-			<li>$node->extra2 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra2 page property.</li>
-			<li>$node->extra3 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra3 page property.</li>
-			<li>$node->image -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the image page property (if non empty)</li>
-			<li>$node->thumbnail -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the thumbnail page property (if non empty)</li>
-			<li>$node->target -- Applicable only when the loadprops parameter is supplied in the menu tag, this field contains Target for the link.  Will be empty if content does not set it.</li>
+			<li>$node->extra1 -- This field contains the value of the extra1 page property, unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->extra2 -- This field contains the value of the extra2 page property, unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->extra3 -- This field contains the value of the extra3 page property, unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->image -- This field contains the value of the image page property (if non empty), unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->thumbnail -- This field contains the value of the thumbnail page property (if non empty), unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->target -- This field contains Target for the link (if non empty), unless the loadprops-parameter is set to NOT load the properties.</li>
 			<li>$node->created -- Item creation date</li>
 			<li>$node->modified -- Item modified date</li>
 			<li>$node->index -- Count of this node in the whole menu</li>
 			<li>$node->parent -- True if this node is a parent of the currently selected page</li>
+			<li>$node->current -- True if this node is the currently selected page</li>
 		</ul>
-	</p>';
-$lang['importtemplate'] = 'Importeer sjabloon naar de database';
+	</p>
+        <h3>Caching</h3>
+        <p>This module has the capability to cache its output into static files to reduce memory requirements and sql queries, and to improve frontend performance.  This provides all the advantages of static menus without the inconvenience involved when creating or editing pages.</p>
+        <p>Each menu template can be marked as &amp;quot;Cachable&amp;quot;. When a cachable menu template is used on a content page that is cachable, any cached menu output that is available for thsi page will be used.  The nocache parameter on the menu tag can be used to completely disable caching.</p>
+        <p>All cached menu files are erased when a content item is added, edited, or deleted... and also when a menu template is added/edited or deleted.</p>';
+$lang['importtemplate'] = 'Importeer dit menusjabloon in de database om het te kunnen wijzigen (Naam zonder extentie invoeren)';
 $lang['menumanager'] = 'Menubeheer';
 $lang['newtemplate'] = 'Sjabloonnaam';
 $lang['nocontent'] = 'Er is geen inhoud ingevoerd';
@@ -91,9 +105,9 @@ $lang['notemplatefiles'] = 'Er zijn geen bestandssjablonen in %s';
 $lang['notemplatename'] = 'Er is geen sjabloonnaam opgegeven.';
 $lang['templatecontent'] = 'Sjablooninhoud';
 $lang['templatenameexists'] = 'Er bestaat al een sjabloon met deze naam';
-$lang['utma'] = '156861353.1269027775.1259416186.1272218404.1272223467.687';
-$lang['utmz'] = '156861353.1272204468.681.121.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,43441.0.html';
-$lang['qca'] = 'P0-431297011-1259416186230';
+$lang['qca'] = 'P0-1157065314-1313856308297';
+$lang['utma'] = '156861353.2142447818.1316276872.1316276872.1316276872.1';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1272223467';
+$lang['utmz'] = '156861353.1316276872.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
