@@ -4,6 +4,9 @@ $lang['help_nocache'] = 'Avaktivera all cache till denna meny. Om denna paramete
 $lang['cachable'] = 'Cachebar';
 $lang['help_childrenof'] = 'Med detta alternativ s&aring; kommer menyn endast att visa objekt som tillh&ouml;r vald page id eller alias. Exempel <code>{menu childrenof=$page_alias}</code> kommer endast att visa undersidor till den aktuella sidan.';
 $lang['usage'] = 'Anv&auml;ndning';
+$lang['import'] = 'Importera';
+$lang['edit'] = 'Redigera';
+$lang['delete'] = 'Radera';
 $lang['help_loadprops'] = 'Anv&auml;nd denna parameter n&auml;r du anv&auml;nder avancerade egenskaper i din meny managermall. Denna parameter tvingar laddningen av all inneh&aring;ll  f&ouml;r varje node (som EXTRA1, bild, miniatyrbilder, etc). och kommer att dramatiskt &ouml;ka antalet s&ouml;kfr&aring;gor som beh&ouml;vs f&ouml;r att bygga upp en meny och minne, men kommer att m&ouml;jligg&ouml;ra mer avancerade menyer.';
 $lang['readonly'] = 'Skrivskyddad';
 $lang['error_templatename'] = 'Du kan inte specificera en mall med fil&auml;ndelsen .tpl';
@@ -76,9 +79,9 @@ $lang['notemplatefiles'] = 'Inga filbaserade mallar i %s';
 $lang['notemplatename'] = 'Inget mallnamn angivet';
 $lang['templatecontent'] = 'Mallinneh&aring;ll';
 $lang['templatenameexists'] = 'En mall med detta namnet finns redan';
-$lang['qca'] = 'P0-1661890032-1292100548202';
-$lang['utma'] = '156861353.1934215823.1299187594.1299227132.1299275456.3';
+$lang['utma'] = '156861353.2084869274.1316417662.1316417662.1316417662.1';
+$lang['utmz'] = '156861353.1316417662.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
+$lang['qca'] = 'P0-1529175659-1310081076901';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1299187594.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353.1.10.1299275456';
 ?>
\ No newline at end of file
