@@ -1,4 +1,24 @@
 <?php
+$lang['error_search'] = 'Chyba pri vyhľad&aacute;van&uacute;';
+$lang['prompt_disable_caching'] = 'Vypn&uacute;ť ke&scaron;ovanie požiadaviek na server';
+$lang['info_disable_caching'] = '<strong>Nedoporučujeme</strong>. Spr&aacute;vca module pre zv&yacute;&scaron;enie r&yacute;chlosti ke&scaron;uje d&aacute;ta (v prednastavenom stave 1 hodina)';
+$lang['operation_results'] = 'V&yacute;sledok oper&aacute;cie';
+$lang['error_noresults'] = 'Očak&aacute;vali sme, že niektor&eacute; v&yacute;sledky maj&uacute; byť k dispoz&iacute;cii z poradia. Pros&iacute;m, sk&uacute;ste reprodukovať toto zistenie, a poskytite dostatočn&eacute; inform&aacute;cie pre podporu.';
+$lang['versionsformodule'] = 'Dostupn&aacute; verzia modulu %s';
+$lang['yourversion'] = 'Va&scaron;a verzia';
+$lang['latestdepends'] = 'Vždy in&scaron;talovať nov&scaron;iu verziu';
+$lang['info_latestdepends'] = 'Ak in&scaron;alujete modul z&aacute;vysli od in&yacute;ch modulov, t&aacute;to voľba skontroluje, či m&aacute;te naozaj nain&scaron;talovan&eacute; najnov&scaron;ie verzie t&yacute;chto modulov.';
+$lang['error_internal'] = 'Intern&aacute; chyba. Pros&iacute;m reportuje chybu svojmu administr&aacute;torovi.';
+$lang['error_downloadxml'] = 'Probl&eacute;m pri preberan&uacute; XML s&uacute;boru: %s';
+$lang['error_request_problem'] = 'Probl&eacute;m pri komunik&aacute;cie so serverom';
+$lang['error_searchterm'] = 'Pros&iacute;m zadajte vyhľad&aacute;vaci dotaz';
+$lang['search_noresults'] = 'Neboli n&aacute;jdene žiadne položky';
+$lang['advancedsearch_help'] = 'Konrektizujte hľadan&eacute; slova pomocou +,- (vr&aacute;tane, okrem), napr&iacute;klad fr&aacute;zu s &uacute;vodzovkami &quot;+červen&eacute; -jablko+&quot;nejak&yacute; text&quot;';
+$lang['search_results'] = 'V&yacute;sledky vyhľad&aacute;vania';
+$lang['prompt_advancedsearch'] = 'Roz&scaron;&iacute;ren&eacute; vyhľad&aacute;vanie';
+$lang['search_input'] = 'Vyhľad&aacute;vanie';
+$lang['searchterm'] = 'Vyhľad&aacute;vac&iacute; dotaz';
+$lang['search'] = 'Vyhľad&aacute;vanie';
 $lang['available_updates'] = 'Moduly dostupn&eacute; pre aktualiz&aacute;ciu';
 $lang['all_modules_up_to_date'] = 'Nie s&uacute; žiadne nov&scaron;ie moduly v repozit&aacute;ry';
 $lang['error_module_object'] = 'Chyba: nem&ocirc;že z&iacute;skať in&scaron;tanciu modulu %s';
@@ -6,8 +26,19 @@ $lang['error_nomatchingmodules'] = 'Chyba: nebola n&aacute;jden&aacute; zhoda v
 $lang['error_nomodules'] = 'Chyba: nenač&iacute;tan&yacute; zoznam použit&yacute;ch modulo';
 $lang['upgrade_available'] = 'Nov&scaron;ia verzia dostupn&aacute; (%s), vy m&aacute;te (%s)';
 $lang['newversions'] = 'Nain&scaron;talovan&eacute; moduly';
-$lang['error_depends'] = 'Nie s&uacute; nain&scaron;talovan&eacute; niektor&eacute; moduly, na ktor&eacute; je in&scaron;talovan&yacute; modul z&aacute;visl&yacute;.  Mus&iacute;te najpr nain&scaron;talovať tie.';
+$lang['notice_depends'] = '%s depends on the following actions. Click &quot;Install&quot; to go ahead.';
+$lang['install_submit'] = 'In&scaron;talovať';
+$lang['depend_upgrade'] = 'Modul %s potrebuje aktualizovať na verziu %s.';
+$lang['depend_install'] = 'Modul %s (verzia %s alebo niž&scaron;ia) potrebuje nain&scaron;talovať.';
+$lang['depend_activate'] = 'Modul %s potrebuje byť aktitovan&yacute;.';
+$lang['action_activated'] = 'Modul %s bol aktivovan&yacute;.';
+$lang['action_installed'] = 'Modul %s nain&scaron;talovan&yacute; s nasleduj&uacute;cou spr&aacute;vou: %s';
+$lang['action_upgraded'] = 'Modul %s bol aktualizovan&yacute;';
+$lang['title_installation_complete'] = 'In&scaron;tal&aacute;cia kompletn&aacute;.';
+$lang['install_with_deps'] = 'Overiť z&aacute;vistlosti a nain&scaron;talovať';
 $lang['msg_nodependencies'] = 'Tento s&uacute;bor nem&aacute; žiadnu z&aacute;vislosť.';
+$lang['error_upgrade'] = 'Aktualiz&aacute;cia modulu %s s chybou!';
+$lang['error_skipping'] = 'Preskoči in&scaron;tal&aacute;ciu/aktualiz&aacute;ciu %s z d&ocirc;vodu chyby pri nastaveniach z&aacute;vislost&iacute;. Pros&iacute;m preč&iacute;tajte si niž&scaron;ie chybov&uacute; spr&aacute;vu a vysk&uacute;&scaron;ajte znovu.';
 $lang['dependstxt'] = 'Z&aacute;vislosti';
 $lang['use_at_your_own_risk'] = 'Použitie na vlastn&eacute; nepezpečenstvo';
 $lang['compatibility_disclaimer'] = 'The modules displayed here are contributed by both the CMS Developers, and independant third parties.  We make no guarantees that the modules available here are functional, tested, or compatible with your system.  You are encouraged to read the information found in the help and about links for each module before attempting the installation.';
@@ -25,24 +56,29 @@ $lang['prompt_dl_chunksize'] = 'Veľkosť sťahovateľnej časti (Kb)';
 $lang['text_dl_chunksize'] = 'Maxim&aacute;lne množstvo d&aacute;t pre stiahnutie v jednej časti (keď in&scaron;talujete modul)';
 $lang['error_nofilesize'] = 'Veľkosť s&uacute;boru  nezn&aacute;my';
 $lang['error_nofilename'] = 'N&aacute;zov s&uacute;boru nezn&aacute;my';
+$lang['error_unsatisfiable_dependency'] = 'Nen&aacute;jden&eacute; vyžadovan&eacute; moduly &quot;%s&quot; (verzia %s alebo vy&scaron;&scaron;ia) v repozit&aacute;ri. Priamo vyžaduje %s; čo m&ocirc;že znamenať probl&eacute;my s touto verziou v repozit&aacute;ri. Pros&iacute;m kontaktujte v&yacute;voj&aacute;ra modulu.';
 $lang['error_checksum'] = 'Chyba kontroln&eacute;ho s&uacute;čtu.  Vznik&aacute; v&auml;č&scaron;inou chybn&yacute;m nahrat&iacute;m s&uacute;boru do repozit&aacute;ra, alebo probl&eacute;mom pri sťahovan&iacute; na v&aacute;&scaron; server.';
 $lang['cantdownload'] = 'Nie je možn&eacute; stiahovať';
-$lang['download'] = 'Stiahn&uacute;ť a nian&scaron;talovať';
+$lang['download'] = 'Stiahn&uacute;ť a nain&scaron;talovať';
 $lang['error_moduleinstallfailed'] = 'In&scaron;tal&aacute;cia modulu ne&uacute;spe&scaron;n&aacute;';
 $lang['error_connectnomodules'] = 'Aj keď pripojenie k repozit&aacute;ru prebehlo &uacute;spe&scaron;ne, vypad&aacute; to tak, že repozit&aacute;r  aktu&aacute;lne nezobrazuje žiadne data.';
 $lang['submit'] = 'Odoslať';
 $lang['text_repository_url'] = 'Adresa vo formul&aacute;ri m&ocirc;že byť http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
 $lang['prompt_repository_url'] = 'Adresa zdroja repozit&aacute;ra modulov';
+$lang['title_installation'] = 'In&scaron;tal&aacute;cia';
 $lang['availmodules'] = 'Dostupn&eacute; moduly';
 $lang['preferences'] = 'Nastavenia';
 $lang['preferencessaved'] = 'Nastavenia uložen&eacute;';
 $lang['repositorycount'] = 'Moduly n&aacute;jden&eacute; v repozit&aacute;ry';
 $lang['instcount'] = 'Nain&scaron;talovan&eacute; moduly';
 $lang['availablemodules'] = 'S&uacute;časn&yacute; stav modulov dostupn&eacute; v repozit&aacute;ri';
+$lang['time_warning'] = 'Zoznam modul pre in&scaron;tal&aacute;ciu obsahuje viac ako1-2 moduly. Budte opatrn&yacute;, in&scaron;tal&aacute;cia m&ocirc;že trvať  niekoľko min&uacute;t';
 $lang['helptxt'] = 'Pomocn&iacute;k k modulu';
 $lang['abouttxt'] = 'O module';
 $lang['xmltext'] = 'XML s&uacute;bor';
 $lang['nametext'] = 'N&aacute;zov modulu';
+$lang['mod_name_ver'] = '%s verzia %s';
+$lang['unknown'] = 'Nezn&aacute;me';
 $lang['vertext'] = 'Verzia';
 $lang['sizetext'] = 'Veľkosť (kilobajty)';
 $lang['statustext'] = 'Stav/Akcia';
@@ -51,8 +87,6 @@ $lang['install'] = 'in&scaron;talovať';
 $lang['newerversion'] = 'Je nain&scaron;talovan&aacute; nov&scaron;ia verzia';
 $lang['onlynewesttext'] = 'Zobraziť iba najnov&scaron;iu verziu';
 $lang['upgrade'] = 'Aktualiz&aacute;cia';
-$lang['error_nosoapconnect'] = 'Nem&ocirc;žem sa pripojiť k serveru SOAP';
-$lang['error_soaperror'] = 'Problem u SOAP';
 $lang['error_norepositoryurl'] = 'Addresa pre repozit&aacute;r modul nebol zadan&yacute;';
 $lang['friendlyname'] = 'Spr&aacute;va modulov';
 $lang['postinstall'] = 'Modul Spr&aacute;va modulov vol &uacute;spe&scaron;ne nain&scaron;talovan&yacute;';
@@ -61,7 +95,8 @@ $lang['really_uninstall'] = 'Ste si ist&yacute;, že chcete odin&scaron;talovať
 $lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
 $lang['installed'] = 'Modul verzia %s nain&scaron;talovan&yacute;.';
 $lang['upgraded'] = 'Modul aktualizovan&yacute; na verziu %s.';
-$lang['moddescription'] = 'A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.';
+$lang['moddescription'] = 'Klient pre repozit&aacute;r modulov, umožňuje n&aacute;hľad a in&scaron;tal&aacute;ciu modulov zo serverou bez použitia FTP alebo rozbaľovania, Moduly vo form&aacute;te XML s&uacute; &scaron;tahovan&eacute; cez protokol SOAP, verifikovan&eacute; a automatick&yacute; nahr&aacute;van&eacute;.';
+$lang['back_to_module_manager'] = '&laquo; n&aacute;vrat do spr&aacute;vcu modulov';
 $lang['error'] = 'Chyba!';
 $lang['admindescription'] = 'N&aacute;stroj pre vyhľad&aacute;vanie a in&scaron;talovanie modulov cez vzdialen&yacute; server.';
 $lang['accessdenied'] = 'Pr&iacute;stup zamietnut&yacute;. Pros&iacute;m skontrolujte svoje pr&aacute;va.';
@@ -108,9 +143,8 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <h3>Copyright and License</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
-$lang['utma'] = '156861353.1778128505.1254062200.1254853045.1254947301.5';
-$lang['utmz'] = '156861353.1254853045.4.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,37973.0.html';
-$lang['qca'] = 'P0-1906760565-1254062200174';
-$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.397069566.1316370484.1316370484.1316453841.2';
+$lang['utmz'] = '156861353.1316453841.2.2.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
