@@ -1,4 +1,11 @@
 <?php
+$lang['error_insufficientparams'] = 'Insufficient (or empty) parameters';
+$lang['error_duplicatename'] = 'An item with that name already exists';
+$lang['detail_page'] = 'Detail Page';
+$lang['detail_template'] = 'Detail Template';
+$lang['warning_preview'] = 'Warning: This preview panel behaves much like a browser window allowing you to navigate away from the initially previewed page. However, if you do that, you may experience unexpected behaviour.  Navigating away from the initial page and returning will not give the expected results.<br/><strong>Note:</strong> The preview does not upload files you may have selected for upload.';
+$lang['article'] = 'Article';
+$lang['preview'] = 'Preview';
 $lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
 $lang['title_detail_returnid'] = 'Default page to use for detail views';
 $lang['title_submission_settings'] = 'News Submission Settings';
@@ -88,7 +95,7 @@ $lang['title_form_sysdefault'] = 'Default Form Template';
 $lang['title_summary_sysdefault'] = 'Default Summary Template';
 $lang['title_detail_sysdefault'] = 'Default Detail Template';
 $lang['info_sysdefault2'] = '<strong>Note:</strong> This tab contains text areas to allow you to edit a set of templates that are displayed when you create a \'new\' summary, detail, or form template.  Changing content in this tab, and clicking \'submit\' will <strong>not effect any current displays</strong>.';
-$lang['info_sysdefault'] = '<em>(the content used by default when a new template is created)</em>';
+$lang['info_sysdefault'] = '(the content used by default when a new template is created)';
 $lang['template'] = 'Template';
 $lang['prompt_name'] = 'Name';
 $lang['prompt_default'] = 'Default';
@@ -145,6 +152,7 @@ $lang['filter'] = 'Filter';
 $lang['more'] = 'More';
 $lang['category_label'] = 'Category:';
 $lang['author_label'] = 'Posted by:';
+$lang['extra_label'] = 'Extra:';
 $lang['moretext'] = 'More Text';
 $lang['name'] = 'Name';
 $lang['news'] = 'News';
@@ -181,62 +189,62 @@ $lang['eventdesc-NewsArticleAdded'] = 'Sent when an article is added.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"news_id\" - Id of the news article</li>
-<li>\"category_id\" - Id of the category for this article</li>
-<li>\"title\" - Title of the article</li>
-<li>\"content\" - Content of the article</li>
-<li>\"summary\" - Summary of the article</li>
-<li>\"status\" - Status of the article ("draft" or "publish")</li>
-<li>\"start_time\" - Date the article should start being displayed</li>
-<li>\"end_time\" - Date the article should stop being displayed</li>
-<li>\"useexp\" - Whether the expiration date should be ignored or not</li>
+<li>"news_id" - Id of the news article</li>
+<li>"category_id" - Id of the category for this article</li>
+<li>"title" - Title of the article</li>
+<li>"content" - Content of the article</li>
+<li>"summary" - Summary of the article</li>
+<li>"status" - Status of the article ("draft" or "publish")</li>
+<li>"start_time" - Date the article should start being displayed</li>
+<li>"end_time" - Date the article should stop being displayed</li>
+<li>"useexp" - Whether the expiration date should be ignored or not</li>
 </ul>
 ';
 $lang['eventdesc-NewsArticleEdited'] = 'Sent when an article is edited.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"news_id\" - Id of the news article</li>
-<li>\"category_id\" - Id of the category for this article</li>
-<li>\"title\" - Title of the article</li>
-<li>\"content\" - Content of the article</li>
-<li>\"summary\" - Summary of the article</li>
-<li>\"status\" - Status of the article ("draft" or "publish")</li>
-<li>\"start_time\" - Date the article should start being displayed</li>
-<li>\"end_time\" - Date the article should stop being displayed</li>
-<li>\"useexp\" - Whether the expiration date should be ignored or not</li>
+<li>"news_id" - Id of the news article</li>
+<li>"category_id" - Id of the category for this article</li>
+<li>"title" - Title of the article</li>
+<li>"content" - Content of the article</li>
+<li>"summary" - Summary of the article</li>
+<li>"status" - Status of the article ("draft" or "publish")</li>
+<li>"start_time" - Date the article should start being displayed</li>
+<li>"end_time" - Date the article should stop being displayed</li>
+<li>"useexp" - Whether the expiration date should be ignored or not</li>
 </ul>
 ';
 $lang['eventdesc-NewsArticleDeleted'] = 'Sent when an article is deleted.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"news_id\" - Id of the news article</li>
+<li>"news_id" - Id of the news article</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryAdded'] = 'Sent when a category is added.';
 $lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"category_id\" - Id of the news category</li>
-<li>\"name\" - Name of the news category</li>
+<li>"category_id" - Id of the news category</li>
+<li>"name" - Name of the news category</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryEdited'] = 'Sent when a category is edited.';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"category_id\" - Id of the news category</li>
-<li>\"name\" - Name of the news category</li>
-<li>\"origname\" - The original name of the news category</li>
+<li>"category_id" - Id of the news category</li>
+<li>"name" - Name of the news category</li>
+<li>"origname" - The original name of the news category</li>
 </ul>
 ';
 $lang['eventdesc-NewsCategoryDeleted'] = 'Sent when a category is deleted.';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
 <h4>Parameters</h4>
 <ul>
-<li>\"category_id\" - Id of the deleted category </li>
-<li>\"name\" - Name of the deleted category</li>
+<li>"category_id" - Id of the deleted category </li>
+<li>"name" - Name of the deleted category</li>
 </ul>
 ';
 
@@ -259,7 +267,7 @@ $lang['helpaction'] = <<<EOT
 <ul>
 <li>&quot;detail&quot; - to display a specified articleid in detail mode.</li>
 <li>&quot;default&quot; - to display the summary view</li>
-<li>&quot;fesubmit&quot; - to display the frontend form for allowing users to submit news articles on the front end.</li>
+<li>&quot;fesubmit&quot; - to display the frontend form for allowing users to submit news articles on the front end. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected wysiwyg editor. (Site Admin >> Global Settings)</li>
 <li>&quot;browsecat&quot; - to display a browseable category list.</li>
 </ul>
 EOT;
