@@ -1,4 +1,11 @@
 <?php
+$lang['error_insufficientparams'] = 'Param&egrave;tres insuffisant (ou vide)';
+$lang['error_duplicatename'] = 'Un &eacute;l&eacute;ment avec ce nom existe d&eacute;j&agrave;';
+$lang['detail_page'] = 'Page de d&eacute;tail&nbsp;';
+$lang['detail_template'] = 'Gabarit du d&eacute;tail&nbsp;';
+$lang['warning_preview'] = 'Attention : cette page d&#039;aper&ccedil;u se comporte comme une fen&ecirc;tre permettant de naviguer loin de cette page aper&ccedil;u originale. Toutefois, si vous faites cela, attention aux comportements inattendus ! <strong>Note :</strong> la pr&eacute;visualisation ne tient pas compte des fichiers pouvant &ecirc;tre en attente d&#039;upload.';
+$lang['article'] = 'Article ';
+$lang['preview'] = 'Aper&ccedil;u';
 $lang['info_detail_returnid'] = 'Cette pr&eacute;f&eacute;rence est utilis&eacute;e pour d&eacute;termin&eacute;e si une page (et donc un gabarit) sert pour l&#039;affichage des pages de d&eacute;tails. Les URLs individualis&eacute;es ne fonctionneront pas si ce param&egrave;tre n&#039;est pas d&eacute;fini pour une page valide. En outre, si cette pr&eacute;f&eacute;rence est activ&eacute;e, et aucun param&egrave;tre page de d&eacute;tail n&#039;est fourni sur la balise {news}, alors cette valeur sera utilis&eacute;e pour des liens pages de d&eacute;tails';
 $lang['title_detail_returnid'] = 'Page par d&eacute;faut &agrave; utiliser pour des vues de d&eacute;tail';
 $lang['title_submission_settings'] = 'Param&egrave;tres de soumission des articles (News)';
@@ -44,8 +51,8 @@ $lang['error_templatenamexists'] = 'Un gabarit de ce nom existe d&eacute;j&agrav
 $lang['error_noarticlesselected'] = 'Aucun article s&eacute;lectionn&eacute;';
 $lang['reassign_category'] = 'Changer la cat&eacute;gorie par&nbsp;';
 $lang['select'] = 'S&eacute;lectionner';
-$lang['approve'] = 'Mettre le status &agrave; &#039;Publi&eacute;&#039;';
-$lang['revert'] = 'Mettre le status &agrave; &#039;&Eacute;bauche&#039;';
+$lang['approve'] = 'Mettre le statut &agrave; &#039;Publi&eacute;&#039;';
+$lang['revert'] = 'Mettre le statut &agrave; &#039;Brouillon&#039;';
 $lang['hide_summary_field'] = 'Cacher le champ sommaire lors de l&#039;ajout ou de la modification d&#039;articles&nbsp;';
 $lang['textbox'] = 'Champ de texte';
 $lang['checkbox'] = 'Case &agrave; cocher';
@@ -86,7 +93,7 @@ $lang['title_form_sysdefault'] = 'Gabarit de soumission article par d&eacute;fau
 $lang['title_summary_sysdefault'] = 'Gabarit du sommaire par d&eacute;faut';
 $lang['title_detail_sysdefault'] = 'Gabarit du d&eacute;tail par d&eacute;faut';
 $lang['info_sysdefault2'] = '<strong>Note :</strong> cette page contient des zones d&#039;&eacute;dition des gabarits qui sont disponibles quand vous cr&eacute;ez un &#039;Nouveau&#039; gabarit Sommaire, D&eacute;tail ou Soumission d&#039;article. Le fait de cliquer sur &#039;Envoyer&#039; les donn&eacute;es de cette page <strong>n&#039;aura aucun effet imm&eacute;diat sur l&#039;affichage d&eacute;j&agrave; existant</strong>.';
-$lang['info_sysdefault'] = '<em>(le gabarit utilis&eacute; par d&eacute;faut quand un nouveau gabarit est s&eacute;lectionn&eacute;)</em>';
+$lang['info_sysdefault'] = '(le gabarit utilis&eacute; par d&eacute;faut quand un nouveau gabarit est s&eacute;lectionn&eacute;)';
 $lang['template'] = 'Gabarit&nbsp;';
 $lang['prompt_name'] = 'Nom';
 $lang['prompt_default'] = 'D&eacute;faut';
@@ -102,7 +109,7 @@ $lang['prompt_pagelimit'] = 'Nombre par page&nbsp;';
 $lang['prompt_sorting'] = 'Tri&eacute; par&nbsp;';
 $lang['title_filter'] = 'Filtres';
 $lang['published'] = 'Publi&eacute;';
-$lang['draft'] = '&Eacute;bauche';
+$lang['draft'] = 'Brouillon';
 $lang['expired'] = 'Expir&eacute;';
 $lang['author'] = 'Auteur&nbsp;';
 $lang['sysdefaults'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
@@ -143,6 +150,7 @@ $lang['filter'] = 'Filtre';
 $lang['more'] = 'Plus';
 $lang['category_label'] = 'Cat&eacute;gorie&nbsp;:';
 $lang['author_label'] = 'Post&eacute; par&nbsp;:';
+$lang['extra_label'] = 'Extra : ';
 $lang['moretext'] = 'Texte pour ';
 $lang['name'] = 'Nom&nbsp;';
 $lang['news'] = 'Articles';
@@ -255,7 +263,7 @@ $lang['helpaction'] = 'Outrepasse l&#039;action par d&eacute;faut. Les valeurs p
 <ul>
 <li>&quot;detail&quot; - pour afficher l&#039;article en mode d&eacute;tail.</li>
 <li>&quot;default&quot; - pour afficher le sommaire de l&#039;article</li>
-<li>&quot;fesubmit&quot; - pour afficher le gabarit de soumission (frontend) d&#039;articles des utilisateurs dans les pages du site.</li>
+<li>&quot;fesubmit&quot; - pour afficher le gabarit de soumission (frontend) d&#039;articles des utilisateurs dans les pages du site. Ajouter le <code>{cms_init_editor}</code> dans la section des m&eacute;ta-donn&eacute;es pour initialiser l&#039;&eacute;diteur WYSIWYG s&eacute;lectionn&eacute; (Administration du site/Param&egrave;tres globaux/WYSIWYG de la partie publique).</li>
 <li>&quot;browsecat&quot; - pour afficher une liste de cat&eacute;gories.</li>
 </ul>
 
@@ -286,9 +294,4 @@ $lang['help'] = '<h3>Notes Importantes</h3>
 <li>Cliquer sur le bouton Envoyer</li>
 </ul>
 <p>Ces diff&eacute;rentes &eacute;tapes r&eacute;solvent le probl&egrave;me de ces nouveaux gabarits afin d&#039;&eacute;viter les diff&eacute;rentes erreurs de Smarty quand vous mettez &agrave; jour vers une version de CMS avec un module de News version 2.3 ou sup&eacute;rieure.</p>';
-$lang['qca'] = 'P0-1532147203-1273233257739';
-$lang['utma'] = '156861353.1552570550.1277739492.1284456886.1284478759.4';
-$lang['utmz'] = '156861353.1284138366.2.2.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
