@@ -1,4 +1,20 @@
 <?php
+$lang['error_insufficientparams'] = 'Verkeerde (of lege) parameters';
+$lang['error_duplicatename'] = 'Er bestaat al een item met deze naam';
+$lang['detail_page'] = 'Detail Pagina';
+$lang['detail_template'] = 'Detail Sjabloon';
+$lang['warning_preview'] = 'Waarschuwing: Dit voorbeeld panel gedraagt ​​zich als een browser-venster waarmee u kunt navigeren van de aanvankelijk bekeken pagina. Echter, als je dat doet, kan er onverwacht gedrag optreden. Navigeren vanaf de huidige pagina en terugkeren zal mogelijk niet het verwachte resultaat geven. <br/><strong>Opmerking:</ strong> De preview upload geen bestanden die u hebt geselecteerd voor uploaden.';
+$lang['article'] = 'Artikel';
+$lang['preview'] = 'Voorbeeld';
+$lang['info_detail_returnid'] = 'Deze instelling wordt gebruikt om een pagina (en dus een sjabloon) te bepalen om te gebruiken om het detail artikel te tonen. Ge&iuml;ndividualiseerde Nieuws Detail URL&#039;s zullen niet werken als deze parameter niet is ingesteld op een geldige pagina.<br />
+Bovendien, als deze voorkeur is ingesteld en de News tag is niet voorzien van de detailpage parameter, dan zal deze waarde worden gebruikt voor de detail links';
+$lang['title_detail_returnid'] = 'Standaard pagina voor detail vertoningen';
+$lang['title_submission_settings'] = 'Nieuws Aanmelding Instellingen';
+$lang['title_fesubmit_settings'] = 'Frontend Aanmelding Instellingen';
+$lang['title_notification_settings'] = 'Berichtgeving Instellingen';
+$lang['title_detail_settings'] = 'Detail vertoning Instellingen';
+$lang['error_invalidurl'] = 'Verkeerde Url <em>(kan zijn dat deze al in gebruik is, of dat er verkeerde tekens in staan)</em>';
+$lang['url'] = 'Url';
 $lang['expired_searchable'] = 'Verlopen artikelen kunnen verschijnen in de zoekresultaten';
 $lang['helpshowall'] = 'Geef alle artikelen weer, ongeacht de einddatum';
 $lang['error_invaliddates'] = 'Een of meerdere ingegeven datums zijn incorrect';
@@ -78,7 +94,7 @@ $lang['title_form_sysdefault'] = 'Standaard formuliersjabloon';
 $lang['title_summary_sysdefault'] = 'Standaard samenvattingssjabloon';
 $lang['title_detail_sysdefault'] = 'Standaard artikelsjabloon';
 $lang['info_sysdefault2'] = '<strong>Opmerking:</strong> Dit tabblad bevat tekstgebieden om een groep sjablonen te bewerken die getoond worden als u een nieuwssamenvatting, -overzicht of formulier-sjabloon aanmaakt. Veranderen van inhoud in dit tabblad en versturen daarvan heeft <strong>geen effect</strong> op de bestaande weergaven.';
-$lang['info_sysdefault'] = '<em>(de inhoud die standaard wordt gebruikt bij het aanmaken van een nieuw sjabloon)</em>';
+$lang['info_sysdefault'] = '(de inhoud die standaard wordt gebruikt bij het aanmaken van een nieuw sjabloon)';
 $lang['template'] = 'Sjabloon';
 $lang['prompt_name'] = 'Naam';
 $lang['prompt_default'] = 'Standaard';
@@ -135,6 +151,7 @@ $lang['filter'] = 'Filter ';
 $lang['more'] = 'Meer';
 $lang['category_label'] = 'Categorie:';
 $lang['author_label'] = 'Ingezonden door:';
+$lang['extra_label'] = 'Extra :';
 $lang['moretext'] = 'Meer tekst';
 $lang['name'] = 'Naam';
 $lang['news'] = 'Nieuws ';
@@ -229,7 +246,7 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Verzonden als een categorie is verw
 <li>\&quot;name\&quot; - Naam van de verwijderde categorie</li>
 </ul>
 ';
-$lang['help_articleid'] = 'Deze parameter is alleen van toepassing op het detail overzicht. Het specificeerd welk nieuws artikel wordt getoond in het detail overzicht. Als de speciale waarde &#039;-1&#039; wordt  gebruikt dan zal de module het nieuwste, gepubliceerde en niet verlopen artikel tonen';
+$lang['help_articleid'] = 'Deze parameter is alleen van toepassing op het detail overzicht. Het specificeert welk nieuws artikel wordt getoond in het detail overzicht. Als de speciale waarde &#039;-1&#039; wordt  gebruikt dan zal de module het nieuwste, gepubliceerde en niet verlopen artikel tonen';
 $lang['helpnumber'] = 'Maximum aantal te tonen items -- door dit leeg te laten worden alle items getoond. Het is een synoniem voor de pagina limiet parameter.';
 $lang['helpstart'] = 'Begin bij het zoveelste... item -- geen waarde ingevoerd start dan bij het eerste item.';
 $lang['helpcategory'] = 'Toon alleen items van die categorie. <b>Gebruik * achter de naam om onderliggende items te tonen</b>. Meerdere categorie&euml;n scheiden met een komma. Geen waarde laat alle categorie&euml;n zien. Deze parameter kan ook gebruikt worden bij een frontend actie, maar dan kan alleen &eacute;&eacute;n categorie naam worden gebruikt.';
@@ -247,7 +264,7 @@ $lang['helpaction'] = 'Negeer de standaardtaak. Mogelijke waarden zijn:
 <ul>
 <li>&quot;detail&quot; - toon van een specifiek artikel ID de detail weergave.</li>
 <li>&quot;default&quot; - toon de samenvattingsweergave</li>
-<li>&quot;fesubmit&quot; - toon het frontend formulier om (ingelogde) gebruikers de mogelijkheid te geven om nieuwsberichten aan te leveren.</li>
+<li>&quot;fesubmit&quot; - toon het frontend formulier om (ingelogde) gebruikers de mogelijkheid te geven om nieuwsberichten aan te leveren. Voeg de <code>{cms_init_editor}</code> tag toe aan de metadata sectie om de geselecteerde WYSIWYG editor toe te passen. (Websitebeheer >> Algemene Instellingen)</li>
 <li>&quot;browsecat&quot; - toon een overzichtslijst van categori&euml;n.</li>
 </ul>';
 $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
@@ -279,9 +296,9 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 <li>Klik Versturen</li>
 </ul>
 Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
-$lang['utma'] = '156861353.1269027775.1259416186.1271008961.1271013397.628';
-$lang['utmz'] = '156861353.1271013397.628.109.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,42884.0/topicseen.html';
-$lang['qca'] = 'P0-431297011-1259416186230';
+$lang['qca'] = 'P0-1157065314-1313856308297';
+$lang['utma'] = '156861353.1414653339.1316370951.1316370951.1316370951.1';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1271013397';
+$lang['utmz'] = '156861353.1316370951.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
