@@ -1,13 +1,26 @@
 <?php
+$lang['error_insufficientparams'] = 'Nespr&aacute;vne (alebo pr&aacute;zdne) zadan&eacute; parametre';
+$lang['error_duplicatename'] = 'Položka s t&yacute;mto n&aacute;zvom už existuje';
+$lang['detail_page'] = 'Str&aacute;nka pre detaily';
+$lang['detail_template'] = '&Scaron;abl&oacute;na detailu';
+$lang['warning_preview'] = 'Upozornenie: Z&aacute;ložka n&aacute;hľadu umožuje zobraziť aktu&aacute;lnu novinku bez uloženie. Av&scaron;ak pri zložit&yacute;ch &uacute;pravach, sa nem&uacute;s&iacute; n&aacute;hľad zobraziť korektne<br/><strong>Pozn&aacute;mka:</strong>  N&aacute;hľad nezobraz&iacute; obr&aacute;zky, ktor&eacute; m&aacute;te vybran&eacute; pre nahratie v nahr&aacute;vacom poli.';
+$lang['article'] = 'Čl&aacute;nok';
+$lang['preview'] = 'N&aacute;hľad';
+$lang['info_detail_returnid'] = 'Parameter služi na zobrazenie novinky na vybranej detailnej str&aacute;nke. Vlastn&eacute; URL nebud&uacute; fungovať ak nebude tento parameter nastaven&yacute; na korektn&uacute; str&aacute;nku. Pokiaľ je ale nastaven&aacute; t&aacute;to voľba a detailpage parameter nebude zadan&yacute; v značke News, použije sa pre zobrazenie detailu d&aacute;to voľba.';
+$lang['title_detail_returnid'] = 'Prednastaven&eacute; str&aacute;nka rpe detail';
+$lang['title_submission_settings'] = 'Nastavenie odoslania noviniek ';
+$lang['title_fesubmit_settings'] = 'Nastavenie odoslania cez web';
+$lang['title_notification_settings'] = 'Nastavenia notifik&aacute;cie';
+$lang['title_detail_settings'] = 'Nastavenie detailu';
+$lang['error_invalidurl'] = 'Neplatn&aacute; URL <em>(buď už existuje, alebo obsahuje neplatn&eacute; znaky)</em>';
+$lang['url'] = 'URL adresa';
 $lang['expired_searchable'] = 'Vypr&scaron;an&eacute; čl&aacute;nky sa m&ocirc;žu objaviť vo v&yacute;sledkoch vyhľad&aacute;vania';
 $lang['helpshowall'] = 'Zobraziť v&scaron;etky čl&aacute;nky, bez ohľadu na d&aacute;tum konca';
 $lang['error_invaliddates'] = 'D&aacute;tumy boli vložen&eacute; nespr&aacute;vne';
 $lang['notify_n_draft_items_sub'] = '%d novinka';
 $lang['notify_n_draft_items'] = 'M&aacute;te %s ktor&eacute; nie je/s&uacute; publikovan&eacute;';
-$lang['helprsscategory'] = 'Pri použ&iacute;van&iacute;i parametru makerssbutton, t&yacute;mto nastavujete kateg&oacute;riu  pre RSS';
 $lang['unlimited'] = 'Bez obmedzenia';
 $lang['none'] = 'Žiadne';
-$lang['rss_destinationpage'] = 'PageId alebo alias str&aacute;nky pre pre novinky z RSS';
 $lang['anonymous'] = 'Anonym';
 $lang['unknown'] = 'Nezn&aacute;my';
 $lang['fesubmit_redirect'] = 'PageID alebo alias  pre presmerovanie po pridan&iacute; novinky odoslanej cez front-end formul&aacute;r';
@@ -22,6 +35,8 @@ $lang['expiry_date_desc'] = 'D&aacute;tum expir&aacute;cie - zostupne';
 $lang['expiry_date_asc'] = 'D&aacute;tum expir&aacute;cie - vzostupne';
 $lang['title_desc'] = 'Nadpis - zostupne';
 $lang['title_asc'] = 'Nadpis - vzostupne';
+$lang['status_desc'] = 'Stav vzostupne';
+$lang['status_asc'] = 'Stav zostupne';
 $lang['fesubmit_status'] = 'Stav novinky po odoslan&iacute; cez front-end';
 $lang['error_invalidfiletype'] = 'Nie je možn&eacute; nahrať tento typ s&uacute;boru';
 $lang['error_upload'] = 'Probl&eacute;m pri nahr&aacute;van&iacute; s&uacute;boru';
@@ -135,6 +150,7 @@ $lang['filter'] = 'Filtre';
 $lang['more'] = 'Viac';
 $lang['category_label'] = 'Kateg&oacute;ria:';
 $lang['author_label'] = 'Publikovan&eacute;:';
+$lang['extra_label'] = 'Extra: ';
 $lang['moretext'] = 'Viac textu';
 $lang['name'] = 'Meno';
 $lang['news'] = 'Novinky';
@@ -153,8 +169,6 @@ $lang['numbertodisplay'] = 'Zobraziť počet (pr&aacute;zdne pre v&scaron;etky z
 $lang['print'] = 'Tlačiť';
 $lang['postdate'] = 'D&aacute;tum publikovania';
 $lang['postinstall'] = 'Uistite sa, že použ&iacute;vatelia ktor&iacute; bud&uacute; spravovať novinky, maj&uacute; nastaven&eacute; opr&aacute;vnenie &quot;Modify News&quot;.';
-$lang['rssfeedtitle'] = 'CMS Made Simple RSS Obsah';
-$lang['rsstemplate'] = 'RSS &scaron;abl&oacute;na';
 $lang['selectcategory'] = 'Vybrať kateg&oacute;riu';
 $lang['showchildcategories'] = 'Zobraziť podriaden&eacute; kateg&oacute;rie';
 $lang['sortascending'] = 'Triediť vzostupne';
@@ -169,8 +183,6 @@ $lang['title'] = 'Nadpis';
 $lang['options'] = 'Voľby';
 $lang['optionsupdated'] = 'Voľby boli &uacute;spe&scaron;ne upraven&eacute;.';
 $lang['useexpiration'] = 'Použ&iacute;ť d&aacute;tum konca';
-$lang['showautodiscovery'] = 'Uk&aacute;zať RSS feed';
-$lang['autodiscoverylink'] = 'Automaticky pridať do hlavičky RSS link pre novinky (napr. /news/rss/)';
 $lang['eventdesc-NewsArticleAdded'] = 'Poslať po pridan&iacute; novinky';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
@@ -233,9 +245,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p
 <li>\&quot;name\&quot; - Name of the deleted category</li>
 </ul>
 ';
+$lang['help_articleid'] = 'Tento parameter je použiteľn&yacute; iba pri použit&iacute; detailu novinky a definuje id konkr&eacute;tnej novnky. Hodnota -1 nastavuje detail najnov&scaron;ej publikovanej, neexpirovanej novinky.';
 $lang['helpnumber'] = 'Maxim&aacute;lny počet položiek k zobrazeniu - ponechan&eacute; pr&aacute;zdne zobraz&iacute; v&scaron;etky položky.';
 $lang['helpstart'] = 'Začiatok zobrazovania od N-tej položky -- ponechan&eacute; pr&aacute;zdne začne zobrazovať od prvej položky';
-$lang['helpmakerssbutton'] = 'Vytvoriť tlač&iacute;tko s odkazom na RSS feed noviniek.';
 $lang['helpcategory'] = 'Zobraziť iba položky t&eacute;jto kateg&oacute;rie a &iacute;ch podpoložiek. Ponechan&eacute; pr&aacute;zdne zobraz&iacute; v&scaron;etky kateg&oacute;rie.';
 $lang['helpmoretext'] = 'Text pre zobrazenie na konci novinky ak presahuje dĺžku s&uacute;hrnu. Predvolen&yacute; je &quot;more...&quot;';
 $lang['helpsummarytemplate'] = 'Použ&iacute;vať oddelen&uacute; &scaron;abl&oacute;nu pre s&uacute;hrn.  T&aacute;to &scaron;abl&oacute;na m&aacute; byť v  modules/News/templates.';
@@ -247,7 +259,7 @@ $lang['helpsortasc'] = 'Triediť novinky vzostupne.';
 $lang['helpdetailpage'] = 'Str&aacute;nka, kde s&aacute; bude zobrazovať detail novinky M&ocirc;že byť ako ID str&aacute;nky alebo alias str&aacute;nky. Použ&iacute;va sa v pr&iacute;pade, keď chcete detail zobraziť v inej &scaron;abl&oacute;ne ako m&aacute;te zobrazen&yacute; s&uacute;hrn.';
 $lang['helpshowarchive'] = 'Uk&aacute;ž star&eacute; pr&iacute;spevky.';
 $lang['helpbrowsecat'] = 'Uk&aacute;že prech&aacute;dzateľn&yacute; zoznam kateg&oacute;ri&iacute;.';
-$lang['helpaction'] = 'Nastavenie prednastavenej akcie. Možn&eacute; hodnoty s&uacute; &#039;default&#039; pre v&yacute;pis a detail novinky a &#039;fesubmit&#039; pre zobrazenie formul&aacute;ra na odoslanie novinky n&aacute;v&scaron;tevn&iacute;kom webu.';
+$lang['helpaction'] = 'Nastavenie prednastavenej akcie. Možn&eacute; hodnoty s&uacute; &#039;default&#039; pre v&yacute;pis a detail novinky , &#039;browsecat&#039; pre zobrazenie kateg&oacute;rii a &#039;fesubmit&#039; pre zobrazenie formul&aacute;ra na odoslanie novinky n&aacute;v&scaron;tevn&iacute;kom webu.';
 $lang['help'] = '<h3>D&ocirc;ležit&eacute; upozornenie</h3>
 <p>Od verzie 2.9 a vy&scaron;&scaron;ej bol z modulu odstr&aacute;nen&yacute; prednastaven&yacute; form&aacute;t d&aacute;tumu a zobrazenie d&aacute;tumu formatpostdate. Namiesto entry->formatpostdate m&ocirc;žete použ&iacute;ť  entry->post_date, alebo  entry->cms_date_format, ktor&yacute; nadefinovan&yacute; v glob&aacute;lnej konfigur&aacute;cii.</p>	
 <h3>Čo rob&iacute; tento modul?</h3>
@@ -284,8 +296,8 @@ $lang['help'] = '<h3>D&ocirc;ležit&eacute; upozornenie</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utmz'] = '156861353.1232905929.143.39.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/projects/ctlmodulemaker';
-$lang['utma'] = '156861353.3723759972012857300.1215977756.1233047582.1233058339.145';
 $lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.397069566.1316370484.1316370484.1316453841.2';
+$lang['utmz'] = '156861353.1316453841.2.2.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
