@@ -1,6 +1,13 @@
 <?php
+$lang['error_insufficientparams'] = 'Otillr&auml;cklig (eller tom) parametrar';
+$lang['error_duplicatename'] = 'Ett objekt med detta namn finns redan';
+$lang['detail_page'] = 'Detaljsida';
+$lang['detail_template'] = 'Detaljmall';
+$lang['warning_preview'] = 'Varning: Denna f&ouml;rhandsgranskning uppf&ouml;r sig i stort sett som ett eget webbl&auml;sar-f&ouml;nster och till&aring;ter att du navigerar bort fr&aring;n den sida du f&ouml;rhandsgranskar. Om du g&ouml;r detta kan du uppleva ett beteende som skiljer sig fr&aring;n det du normalt f&ouml;rv&auml;ntar dig. Om du navigerar bort fr&aring;n den f&ouml;rhandsgranskade sidan och sedan tillbaka till den kommer du inte att f&aring; det f&ouml;rv&auml;ntade resultatet.<br/><strong>Observera:</strong> F&ouml;rhandsgranskningen laddar inte upp filer som du har valt f&ouml;r uppladdning.';
+$lang['article'] = 'Artikel';
+$lang['preview'] = 'F&ouml;rhandsgranskning';
 $lang['info_detail_returnid'] = 'Den h&auml;r inst&auml;llningen anv&auml;nds f&ouml;r att best&auml;mma en sida (och d&auml;rf&ouml;r en mall) som ska anv&auml;ndas f&ouml;r att visa detaljsidor. Individualiserad nyhets-detalj webbadresser kommer inte att fungera om den h&auml;r parametern inte &auml;r satt till en giltig sida. Dessutom, om detta &auml;r inst&auml;llt, och ingen detaljside parameter anges p&aring; nyhets taggen, s&aring; kommer detta v&auml;rde att anv&auml;ndas f&ouml;r detaljl&auml;nkar.';
-$lang['title_detail_returnid'] = 'Standardsida f&ouml;r detalj visning';
+$lang['title_detail_returnid'] = 'Standardsida f&ouml;r detaljvisning';
 $lang['title_submission_settings'] = 'Inst&auml;llningar vid tillagd nyhet';
 $lang['title_fesubmit_settings'] = 'Inst&auml;llningar vid tillagd nyhet fr&aring;n framsidan';
 $lang['title_notification_settings'] = 'Notiferingsinst&auml;llningar';
@@ -143,6 +150,7 @@ $lang['filter'] = 'Filter ';
 $lang['more'] = 'Mer';
 $lang['category_label'] = 'Kategori:';
 $lang['author_label'] = 'Skrivet av:';
+$lang['extra_label'] = 'Extra :';
 $lang['moretext'] = 'Mera text';
 $lang['name'] = 'Namn';
 $lang['news'] = 'Nyheter';
@@ -281,9 +289,9 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.622613290.1282068801.1286133816.1286141542.24';
-$lang['utmz'] = '156861353.1284652314.14.4.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
-$lang['qca'] = 'P0-1267218368-1282068801788';
+$lang['utma'] = '156861353.2084869274.1316417662.1316417662.1316417662.1';
+$lang['utmz'] = '156861353.1316417662.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
+$lang['qca'] = 'P0-1529175659-1310081076901';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1286141542';
 ?>
\ No newline at end of file
