@@ -1,7 +1,7 @@
 <?php
 #CMS - CMS Made Simple
 #(c)2004 by Ted Kulp (wishy@users.sf.net)
-#This project's homepage is: http://cmsmadesimple.sf.net
+#This project's homepage is: http://www.cmsmadesimple.org
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: editcontent.php 6904 2011-02-20 19:42:44Z calguy1000 $
+#$Id: editcontent.php 7396 2011-09-15 12:57:25Z rolf1 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -34,16 +34,6 @@ define('XAJAX_DEFAULT_CHAR_ENCODING', $config['admin_encoding']);
 require_once(dirname(dirname(__FILE__)) . '/lib/xajax/xajax_core/xajax.inc.php');
 require_once(dirname(__FILE__).'/editcontent_extra.php');
 
-$xajax = new xajax();
-$xajax->register(XAJAX_FUNCTION,'ajaxpreview');
-$xajax->processRequest();
-$headtext = $xajax->getJavascript('../lib/xajax')."\n";
-
-if (isset($_POST["cancel"]))
-{
-	redirect("listcontent.php".$urlext);
-}
-
 $error = FALSE;
 
 $content_id = "";
@@ -61,6 +51,18 @@ if (isset($_POST["apply"])) $apply = true;
 $ajax = false;
 if (isset($_POST['ajax']) && $_POST['ajax']) $ajax = true;
 
+$xajax = new xajax();
+$xajax->configure('requestURI',$config['admin_url'].'/editcontent.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY].'&content_id='.$content_id);
+$xajax->register(XAJAX_FUNCTION,'ajaxpreview');
+$xajax->processRequest();
+$headtext = $xajax->getJavascript('../lib/xajax')."\n";
+
+if (isset($_POST["cancel"]))
+{
+	redirect("listcontent.php".$urlext);
+}
+
+
 if ($apply)
 {
 	$CMS_EXCLUDE_FROM_RECENT=1;
@@ -70,7 +72,7 @@ if ($apply)
 #Get a list of content types and pick a default if necessary
 $gCms = cmsms();
 $contentops =& $gCms->GetContentOperations();
-$existingtypes = $contentops->ListContentTypes();
+$existingtypes = $contentops->ListContentTypes(false,true);
 
 #Get current userid and make sure they have permission to add something
 $userid = get_userid();
@@ -107,7 +109,8 @@ if ($access)
     }
   else
     {
-      $error = '<p>'.lang('error_contenttype').'</p>';
+      //$error = '<p>'.lang('error_contenttype').'</p>';
+      redirect("listcontent.php".$urlext."&page=".$pagelist_id.'&error=error_contenttype');
     }
 
   if( $content_id != -1 && strtolower(get_class($contentobj)) != strtolower($content_type) )
@@ -135,7 +138,8 @@ if ($access)
 	      $contentobj->Save();
 	      $contentops =& $gCms->GetContentOperations();
 	      $contentops->SetAllHierarchyPositions();
-	      audit($contentobj->Id(), $contentobj->Name(), 'Edited Content');
+	      // put mention into the admin log
+		  audit($contentobj->Id(), 'Content Item: '.$contentobj->Name(), 'Edited');
 	      if ($submit)
 		{
 		  redirect("listcontent.php".$urlext."&page=".$pagelist_id.'&message=contentupdated');
@@ -176,18 +180,10 @@ if (strlen($contentobj->Name()) > 0)
 
 // Detect if a WYSIWYG is in use, and grab its form submit action
 $addlScriptSubmit = '';
-foreach (array_keys($gCms->modules) as $moduleKey)
+$modobj = cms_utils::get_wysiwyg_module();
+if( $modobj )
 {
-	$module =& $gCms->modules[$moduleKey];
-	if (!($module['installed'] && $module['active'] && $module['object']->IsWYSIWYG()))
-	{
-		continue;
-	}
-
-	if (!$contentobj->GetPropertyValue('disable_wysiwyg') && ($module['object']->WYSIWYGActive() or get_preference(get_userid(), 'wysiwyg') == $module['object']->GetName()))
-	{
-		$addlScriptSubmit .= $module['object']->WYSIWYGPageFormSubmit();
-	}
+  $addlScriptSubmit .= $modobj->WYSIWYGPageFormSubmit();
 }
 
 $closestr = cms_html_entity_decode(lang('close'));
@@ -252,7 +248,7 @@ if (!$access)
 else
 {
 	#Get a list of content_types and build the dropdown to select one
-	$typesdropdown = '<select name="content_type" onchange="document.Edit_Content.submit()" class="standard">';
+	$typesdropdown = '<select name="content_type" id="content_type" onchange="document.Edit_Content.submit()" class="standard">';
 	$cur_content_type = '';
 	foreach ($existingtypes as $onetype => $onetypename )
 	{
@@ -320,7 +316,7 @@ else
 		}
 		
 		#Make a preview tab
-		if ($contentobj->mPreview)
+		if ($contentobj->HasPreview())
 		{
 			echo '<div id="edittabpreview"'.($tmpfname!=''?' class="active"':'').' onclick="##INLINESUBMITSTUFFGOESHERE##xajax_ajaxpreview(xajax.getFormValues(\'Edit_Content\')); return false;">'.lang('preview').'</div>';
 		}
@@ -341,9 +337,9 @@ else
 $submit_buttons = '<div class="pageoverflow">
 <p class="pagetext">&nbsp;</p>
 <p class="pageinput">
- <input type="submit" name="submitbutton" value="'.lang('submit').'" class="pagebutton" onmouseover="this.className=\'pagebuttonhover\'" onmouseout="this.className=\'pagebutton\'" title="'.lang('submitdescription').'" />';
-$submit_buttons .= ' <input type="submit" name="cancel" value="'.lang('cancel').'" class="pagebutton" onmouseover="this.className=\'pagebuttonhover\'" onmouseout="this.className=\'pagebutton\'" title="'.lang('canceldescription').'" />';
-$submit_buttons .= ' <input type="submit" name="apply" value="'.lang('apply').'" class="pagebutton" onmouseover="this.className=\'pagebuttonhover\'" onmouseout="this.className=\'pagebutton\'" title="'.lang('applydescription').'" />';
+ <input type="submit" name="submitbutton" value="'.lang('submit').'" class="pagebutton" title="'.lang('submitdescription').'" />';
+$submit_buttons .= ' <input type="submit" name="cancel" value="'.lang('cancel').'" class="pagebutton" title="'.lang('canceldescription').'" />';
+$submit_buttons .= ' <input type="submit" name="apply" value="'.lang('apply').'" class="pagebutton" title="'.lang('applydescription').'" />';
  if( $contentobj->IsViewable() && $contentobj->Active() ) {
    $submit_buttons .= ' <a rel="external" href="'.$contentobj->GetURL().'">'.$themeObject->DisplayImage('icons/system/view.gif',lang('view_page'),'','','systemicon').'</a>';
  }
@@ -368,7 +364,7 @@ $submit_buttons .= '</p></div>';
 				echo $submit_buttons;
 				?>
 				<div class="pageoverflow">
-					<div class="pagetext"><?php echo lang('contenttype'); ?>:</div>
+					<div class="pagetext"><label for="content_type"><?php echo lang('contenttype'); ?></label>:</div>
 					<div class="pageinput"><?php echo $typesdropdown; ?></div>
 				</div>
 				<?php
@@ -396,7 +392,7 @@ $submit_buttons .= '</p></div>';
 		</div>
 		<?php
 		}
-		if ($contentobj->mPreview)
+		if ($contentobj->HasPreview())
 		{
 			echo '<div class="pageoverflow"><div id="edittabpreview_c"'.($tmpfname!=''?' class="active"':'').'>';
 				?>
