@@ -1,8 +1,18 @@
 <?php
-$lang['test_error_estrict'] = 'Teste error_reporting, um sicherzustellen, dass E_STRICT deaktiviert ist';
+$lang['installed_module'] = 'Modul installiert';
+$lang['automatedtask_success'] = 'Automatische Aufgabenplanung ausgef&uuml;hrt';
+$lang['ip_addr'] = 'IP-Adresse';
+$lang['install_admin_pwsalt_note'] = 'Wenn Sie die Funktion f&uuml;r &quot;gesalzene&#039;&quot; Passw&ouml;rter aktivieren, gibt es absolut KEINE M&ouml;glichkeit mehr, Administrator-Passw&ouml;rter zur&uuml;ckzusetzen (au&szlig;er &uuml;ber die Funktion &quot;Passwort vergessen&quot; bei der Anmeldung). Sie sollten daher zuvor f&uuml;r jeden in der Administration registrierten Nutzer eine g&uuml;ltige Email-Adresse eintragen.';
+$lang['admin_salt'] = 'Gesalzene Administrator-Passw&ouml;rter aktivieren';
+$lang['setup_flat_urls'] = 'Es sind flache URLs eingestellt';
+$lang['install_timezone'] = 'Bei einigen Server, die PHP 5.3 verwenden, wurde die Zeitzone nicht / nicht korrekt eingestellt. Bitte w&auml;hlen Sie daher die Zeitzone f&uuml;r Ihre Webseite aus der Liste aus. Falls dies auf Ihrem Server nicht erforderlich ist, w&auml;hlen Sie &quot;Keine&quot;.
+<strong>Hinweis:</strong> Bitte w&auml;hlen Sie hier die Zeitzone Ihres Servers. Dies ist nicht die Einstellung f&uuml;r die Datumsanzeige, sondern wird f&uuml;r datumsbezogene Berechnung Terminen verwendet. Diese Einstellung kann nach der Installation in der config.php ge&auml;ndert werden.';
+$lang['timezone'] = 'Zeitzone';
+$lang['none'] = 'Keine';
+$lang['test_error_estrict'] = 'Test der Einstellung error_reporting, um sicherzustellen, dass E_STRICT deaktiviert ist';
 $lang['test_estrict_failed'] = 'E_STRICT ist aktiviert';
-$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSms verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie dies, bevor Sie weitermachen.';
-$lang['test_error_edeprecated'] = 'Teste error_reporting, um sicherzustellen, dass E_DEPRECATED deaktiviert ist';
+$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSms verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie diese Einstellung, bevor Sie weitermachen.';
+$lang['test_error_edeprecated'] = 'Test der Einstellung error_reporting, um sicherzustellen, dass E_DEPRECATED deaktiviert ist';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED ist aktiviert';
 $lang['info_edeprecated_failed'] = 'Wenn E_DEPRECATED in Ihren error_reporting Einstellungen aktiviert ist, werden eine ganze Reihe von Warnhinweisen angezeigt, die Auswirkungen auf die Anzeige und die Funktionalit&auml;ten haben k&ouml;nnen.';
 $lang['invalidemail'] = 'Die eingegebene Email-Adresse ist ung&uuml;ltig';
@@ -20,31 +30,31 @@ $lang['test_check_register_globals_failed'] = 'PHP register globals ist auf Ihre
 $lang['test_check_disable_functions'] = 'Pr&uuml;fung auf deaktivierte PHP-Funktionen';
 $lang['test_check_disable_functions_failed'] = 'Dies ist eine Liste der Funktionen, die auf Ihrem Server deaktiviert sind.';
 $lang['install_admin_db_port'] = 'Datenbank-Port';
-$lang['install_admin_db_port_info'] = 'Wenn Sie diesen Wert nicht kennen, lassen Sie ihn leer. Dann wird der serverseitig voreingestellte Datenbank-Port verwendet.';
+$lang['install_admin_db_port_info'] = 'Wenn Sie diesen Wert nicht kennen, lassen Sie ihn leer. Dann werden die serverseitigen Voreinstellungen verwendet.';
 $lang['install_admin_db_socket'] = 'Datenbank-Socket';
 $lang['install_admin_db_socket_info'] = 'AKTUELL NICHT UNTERST&Uuml;TZT.';
-$lang['install_admin_frontendlang'] = 'Voreingestellte Sprache f&uuml;r die Webseite. Der Wert dieses Feldes wird f&uuml;r die Voreinstellung verschiedener Funktionen verwendet (z.Bsp. Datums-Funktionen). Lassen Sie dieses Feld leer, wenn Sie eine mehrsprachige Webseite betreiben oder die Voreinstellungen des Servers verwenden m&ouml;chten.';
+$lang['install_admin_frontendlang'] = 'Voreingestellte Sprache f&uuml;r die Webseite. Der Wert dieses Feldes wird f&uuml;r die Voreinstellung verschiedener Funktionen verwendet (z.Bsp. Datums-Funktionen).';
 $lang['install_default_encoding'] = 'In den meisten F&auml;llen sollte die Standard-Kodierung utf-8 sein. Wenn Sie eine andere Kodierung verwenden m&ouml;chten, k&ouml;nnen Sie dies &auml;ndern. Bitte bedenken Sie jedoch, dass die Sprachdateien alle in utf-8 kodiert sind.';
 $lang['installer_done'] = '[erledigt]';
 $lang['installer_failed'] = '[fehlgeschlagen]';
-$lang['create_permission'] = 'Erstelle Berechtigung ...';
-$lang['add_column_sql'] = 'F&uuml;ge der Tabelle %s eine weitere Spalte hinzu ...';
-$lang['update_table_sql'] = 'Aktualisiere die Tabelle %s ...';
-$lang['installing_module'] = 'Installiere das Modul %s ...';
-$lang['updating_schema_version'] = 'Aktualisiere Schema-Version %s ...';
+$lang['create_permission'] = 'Erstellung der Berechtigung ...';
+$lang['add_column_sql'] = 'Erweiterung der Tabelle %s um eine Spalte ...';
+$lang['update_table_sql'] = 'Aktualisierung der Tabelle %s ...';
+$lang['installing_module'] = 'Installation des Moduls %s ...';
+$lang['updating_schema_version'] = 'Aktualisierung der Schema-Version %s ...';
 $lang['upgrade_config'] = 'Die Datei config.php wird aktualisiert';
 $lang['upgrade_config_info'] = 'Aktualisierung wird konfiguriert';
-$lang['upgrade_failed_again'] = 'Ein oder mehrere Aktualisierungspr&uuml;fungen sind fehlgeschlagen. Bitte beheben Sie das Problem und klicken Sie den unten stehenden Button f&uuml;r eine erneute Pr&uuml;fung.';
+$lang['upgrade_failed_again'] = 'Ein oder mehrere Aktualisierungen sind fehlgeschlagen. Bitte beheben Sie das Problem und klicken Sie den unten stehenden Button f&uuml;r eine erneute Pr&uuml;fung.';
 $lang['upgrade_cache_dirs'] = 'Zwischenspeicher wird geleert';
 $lang['cannot_clean_cache_dirs'] = 'Konnte den Zwischenspeicher nicht leeren!';
 $lang['upgrade_schema'] = 'Schema aktualisieren';
 $lang['need_upgrade_schema'] = 'Ihr CMS ben&ouml;tigt eine Aktualisierung.<br />Sie verwenden aktuell Schema-Version %s und m&uuml;ssen auf Version %s aktualisieren';
-$lang['schema_ok'] = 'Jetzt ist Ihre CMS-Datenbank mit der Schema-Version %s aktuell';
-$lang['noneed_upgrade_schema'] = 'Ihre CMS-Datenbank ist mit der verwendeten Schema-Version %s aktuell';
-$lang['upgrade_modules'] = 'Aktualisiere die Module';
+$lang['schema_ok'] = 'Jetzt ist Ihre CMS-Datenbank ist aktuell. Es wird die Schema-Version %s verwendet.';
+$lang['noneed_upgrade_schema'] = 'Jetzt ist Ihre CMS-Datenbank ist aktuell. Es wird die Schema-Version %s verwendet.';
+$lang['upgrade_modules'] = 'Aktualisierung der Module';
 $lang['noneed_upgrade_modules'] = 'Die Core-Module sind auf dem aktuellsten Stand';
-$lang['upgrade_sql_module_from_to'] = 'Aktualisiere die Datenbank des &quot;%s&quot;-Moduls von %s auf %s ...';
-$lang['upgrade_event_module_from_to'] = 'Aktualisiere die Ereignisse des &quot;%s&quot;-Moduls von %s auf %s ...';
+$lang['upgrade_sql_module_from_to'] = 'Aktualisierung der Datenbank des &quot;%s&quot;-Moduls von %s auf %s ...';
+$lang['upgrade_event_module_from_to'] = 'Aktualisierung der Ereignisse des &quot;%s&quot;-Moduls von %s auf %s ...';
 $lang['sitedown_not_removed'] = 'Die Datei <em>tmp/cache/SITEDOWN</em> konnte nicht entfernen werden. Bitte l&ouml;schen Sie diese Datei manuell, bis dahin wird auf Ihrer Webseite eine Wartungsmeldung angezeigt.';
 $lang['upgrade_ok'] = 'Bitte schauen Sie sich die Datei config.php an, &auml;ndern ggf. die neuen Einstellungen nach Ihren Vorstellungen und setzen dann die Berechtigung f&uuml;r diese Datei auf einen sicheren Wert zur&uuml;ck. Sie sollten au&szlig;erdem pr&uuml;fen, dass alle Module aktuell sind. Dies k&ouml;nnen Sie in der Administration unter &quot;Erweiterungen > Module&quot; pr&uuml;fen. Das jeweilige Modul ist dann mit dem Hinweis &quot;Ben&ouml;tigt eine Aktualisierung&quot; versehen.';
 $lang['upgrade_complete'] = 'Die Aktualisierung wurde erfolgreich beendet';
@@ -73,9 +83,9 @@ $lang['function_file_uploads_off'] = 'Das Hochladen von Dateien ist in Ihrer PHP
 $lang['upload_file_no_readable'] = 'Die hochgeladene Datei ist nicht lesbar!';
 $lang['upload_file_multiple'] = 'Das Hochladen von mehreren Dateien ist nicht erlaubt!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic Quotes f&uuml;r Get/Post/Cookie Aktionen';
-$lang['test_check_magic_quotes_gpc_failed'] = 'Wenn die Einstellung magic_quotes aktiviert ist, wird allen einfachen und doppelten Anf&uuml;hrungszeichen sowie Backslashes automatisch ein Backslash vorangestellt. Das kann einige Probleme beim Betrieb von CMS made simple zur Folge haben.';
+$lang['test_check_magic_quotes_gpc_failed'] = 'Wenn die Einstellung magic_quotes aktiviert ist, wird allen einfachen und doppelten Anf&uuml;hrungszeichen sowie Backslashes automatisch ein Backslash vorangestellt. Das kann einige Probleme beim Betrieb von CMS Made Simple zur Folge haben.';
 $lang['test_check_magic_quotes_runtime'] = 'Magic Quotes zur Laufzeit';
-$lang['test_check_magic_quotes_runtime_failed'] = 'Wenn die Einstellung magic_quotes aktiviert ist, wird den Daten aus externen Quellen (einschlie&szlig;lich Datenbanken und Textdateien) von den meisten Funktionen automatisch ein Backslash vorangestellt. Das kann einige Probleme beim Betrieb von CMS made simple zur Folge haben.';
+$lang['test_check_magic_quotes_runtime_failed'] = 'Wenn die Einstellung magic_quotes aktiviert ist, wird den Daten aus externen Quellen (einschlie&szlig;lich Datenbanken und Textdateien) von den meisten Funktionen automatisch ein Backslash vorangestellt. Das kann einige Probleme beim Betrieb von CMS Made Simple zur Folge haben.';
 $lang['install_admin_checksum'] = 'Ihre Installation pr&uuml;fen';
 $lang['upgrade_admin_checksum'] = 'Ihre System-Aktualisierung pr&uuml;fen';
 $lang['checksum'] = 'Pr&uuml;fsummen-Test';
@@ -86,15 +96,16 @@ $lang['checksum_failed'] = 'Die Pr&uuml;fsumme stimmt mit einigen Fehlern &uuml;
 $lang['test_check_open_basedir'] = 'Pr&uuml;fung auf PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen sind bei Ihnen aktiviert. Aufgrund dieser Beschr&auml;nkung k&ouml;nnen bei bestimmten Funktionalit&auml;ten Probleme auftreten.';
 $lang['unlimited'] = 'Keine Einschr&auml;nkung';
-$lang['test_open_basedir_session_save_path'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen scheint bei Ihnen aktiviert zu sein. Wenn Sie Probleme mit Sessions haben, aber der Befehl ini_set ausgef&uuml;hrt werden kann, k&ouml;nnen Sie versuchen, die Option &quot;session by cookies&quot; zu aktivieren, indem Sie der Datei config.php gleich als erste Zeile folgendes hinzuf&uuml;gen: ini_set(&#039;session.use_only_cookies&#039;, 1);';
-$lang['install_warn_db_createtables'] = 'Normalerweise sollte dieses Feld regelm&auml;&szlig;ig &uuml;berpr&uuml;ft werden. Sie sollten daher wissen, was Sie tun, wenn Sie diese Funktion deaktivieren.';
+$lang['test_open_basedir_session_save_path'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen scheint bei Ihnen aktiviert zu sein. Wenn Sie Probleme mit Sessions haben, aber der Befehl ini_set ausgef&uuml;hrt werden kann, k&ouml;nnen Sie versuchen, die Option &quot;session by cookies&quot; zu aktivieren, indem Sie der Datei config.php gleich als erste Zeile folgendes hinzuf&uuml;gen: 
+<code>ini_set(&#039;session.use_only_cookies&#039;, 1);</code>';
+$lang['install_warn_db_createtables'] = 'Im Normalfall sollte dieses Kontrollfeld aktiviert sein. Sie sollten wissen, was Sie tun, wenn Sie diese Funktion deaktivieren.';
 $lang['install_admin_tablesnotcreated'] = 'Die Installation ist jetzt vollst&auml;ndig. Aufgrund Ihrer Einstellungen wurden die Datenbanktabellen NICHT erzeugt. Die Einstellungen wurden in der Datei config.php wurden gespeichert und alle Tests erfolgreich absolviert.  Vielen Dank, hier ist Ihr';
-$lang['info_create_dir_and_file'] = 'Der httpd-Proze&szlig; konnte keine Datei in eigenen Verzeichnissen erzeugen. Das bedeutet, dass der Safe-Modus auf Ihrem Host aktiviert ist. Ohne diese F&auml;higkeit k&ouml;nnen einige Funktionen von CMS made simple jedoch nicht arbeiten. Die Fortsetzung ist daher nicht m&ouml;glich.';
+$lang['info_create_dir_and_file'] = 'Der httpd-Proze&szlig; konnte keine Datei in eigenen Verzeichnissen erzeugen. Das bedeutet, dass der Safe-Modus auf Ihrem Host aktiviert ist. Ohne diese F&auml;higkeit k&ouml;nnen einige Funktionen von CMS Made Simple jedoch nicht arbeiten. Die Fortsetzung ist daher nicht m&ouml;glich.';
 $lang['test_create_dir_and_file'] = 'Pr&uuml;fung, ob der httpd-Proze&szlig; eine Datei in einem selbst erstellten Verzeichnis erzeugen kann.';
 $lang['cms_site'] = 'CMS-Seite';
 $lang['or_greater'] = 'Oder h&ouml;her';
 $lang['sitename'] = 'Name der Webseite';
-$lang['warning_safe_mode'] = '<strong><em>WARNUNG:</em></strong> Der PHP-Safe-Modus ist auf Ihrem Server aktiviert. Beim Hochladen von Bildern, Themes und Modul-XML-Dateien kann es zu Problemen kommen. Fragen Sie den Server-Administrator, ob er den Safe-Modus deaktiviert.';
+$lang['warning_safe_mode'] = '<strong>WARNUNG:</strong> Der PHP-Safe-Modus ist auf Ihrem Server aktiviert. Beim Hochladen von Bildern, Themes und Modul-XML-Dateien kann es zu Problemen kommen. Fragen Sie den Server-Administrator, ob er den Safe-Modus deaktiviert.';
 $lang['test'] = 'Testen';
 $lang['results'] = 'Ergebnisse';
 $lang['untested'] = 'Nicht getestet';
@@ -125,7 +136,7 @@ $lang['help_systeminformation'] = 'Die hier angezeigten Informationen werden von
 $lang['systeminfo'] = 'System-Informationen';
 $lang['systeminfodescription'] = 'Zeigt bestimmte Informationen Ihres Systems an, die bei der Diagnostizierung von Problemen hilfreich sein k&ouml;nnen';
 $lang['error'] = 'Fehler';
-$lang['new_version_available'] = '<em>ACHTUNG:</em> Eine neue Version von CMS made simple ist verf&uuml;gbar. Bitte kontaktieren Sie Ihren Administrator/Webmaster schnellstm&ouml;glich f&uuml;r eine Aktualisierung.';
+$lang['new_version_available'] = '<em>ACHTUNG:</em> Eine neue Version von CMS Made Simple ist verf&uuml;gbar. Bitte kontaktieren Sie Ihren Administrator/Webmaster schnellstm&ouml;glich f&uuml;r eine Aktualisierung.';
 $lang['info_urlcheckversion'] = 'Wird in diesem Feld &quot;none&quot; eingegeben, erfolgt keine &Uuml;berpr&uuml;fung.<br />Ohne Eintrag wird eine intern vorgegebene URL verwendet.';
 $lang['urlcheckversion'] = '&Uuml;ber diese URL auf neue CMSms-Versionen pr&uuml;fen';
 $lang['read'] = 'Lesen';
@@ -190,12 +201,12 @@ $lang['username'] = 'Benutzername';
 $lang['usernameincorrect'] = 'Benutzername oder Passwort sind falsch';
 $lang['version'] = 'Version ';
 $lang['install_title'] = 'CMS Made Simple - Installation - Schritt %s';
-$lang['install_system'] = 'Installations-System';
-$lang['install_thanks'] = 'Vielen Dank f&uuml;r die Installation von CMS made simple';
-$lang['upgrade_title'] = 'CMS made simple - Aktualisierung - Schritt %s';
+$lang['install_system'] = 'Systeminstallation';
+$lang['install_thanks'] = 'Vielen Dank f&uuml;r die Installation von CMS Made Simple';
+$lang['upgrade_title'] = 'CMS Made Simple - Aktualisierung - Schritt %s';
 $lang['upgrade_system'] = 'Aktualisierungs-System';
-$lang['upgrade_thanks'] = 'Vielen Dank f&uuml;r die Aktualisierung von CMS made simple auf ';
-$lang['install_please_read'] = 'Sollten bei der Installation Probleme auftreten, lesen Sie bitte den Abschnitt <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/de">Fehlersuche</a> im CMS made simple Wiki.';
+$lang['upgrade_thanks'] = 'Vielen Dank f&uuml;r die Aktualisierung von CMS Made Simple auf ';
+$lang['install_please_read'] = 'Sollten bei der Installation Probleme auftreten, lesen Sie bitte den Abschnitt <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/de">Fehlersuche</a> im CMS Made Simple Wiki.';
 $lang['install_checking'] = 'Berechtigungen und PHP-Einstellungen pr&uuml;fen';
 $lang['install_test'] = 'Testen';
 $lang['install_result'] = 'Ergebnis';
@@ -237,7 +248,7 @@ $lang['test_could_not_create_table'] = 'Eine Tabelle konnte nicht erstellt werde
 $lang['test_check_php'] = 'Pr&uuml;fung auf PHP-Version %s+';
 $lang['test_min_recommend'] = '(minimal %s, empfohlen %s oder h&ouml;her)';
 $lang['test_min_recommend_plus'] = '(minimal %s, empfohlen %s+)';
-$lang['test_requires_php_version'] = 'CMS made simple ben&ouml;tigt PHP in der Version 4.3 oder h&ouml;her (Sie haben %s). Um eine maximale Kompatibilit&auml;t mit Erweiterungen von Drittanbietern sicherzustellen, wird die Verwendung von PHP %s oder h&ouml;her empfohlen.';
+$lang['test_requires_php_version'] = 'CMS Made Simple ben&ouml;tigt PHP in der Version 5.2.4 oder h&ouml;her (Sie haben %s). Um eine maximale Kompatibilit&auml;t mit Erweiterungen von Drittanbietern sicherzustellen, wird die Verwendung von PHP %s oder h&ouml;her empfohlen.';
 $lang['test_check_md5_func'] = 'Pr&uuml;fung auf MD5-Funktionen';
 $lang['test_check_safe_mode'] = 'Pr&uuml;fung auf die Verwendung des Safe-Modus';
 $lang['test_check_safe_mode_failed'] = 'Wenn der PHP-Safe-Modus verwendet wird, kann es beim Hochladen von Dateien und anderen Funktionen zu Problemen kommen. Dies ist davon abh&auml;ngig, wie streng die Einstellungen Ihres Servers bez&uuml;glich des Safe-Modus sind.';
@@ -253,7 +264,7 @@ $lang['test_check_xml_func'] = 'Pr&uuml;fung auf einfache XML (expat) Unterst&uu
 $lang['test_check_xml_failed'] = 'Die XML-Unterst&uuml;tzung wurde nicht in Ihre PHP-Installation kompiliert. Sie k&ouml;nnen das System verwenden, aber es ist nicht m&ouml;glich, Module &uuml;ber den ModulManager zu installieren.';
 $lang['test_allow_url_fopen_failed'] = 'Wenn die Funktion &quot;allow url fopen&quot; deaktiviert ist, k&ouml;nnen Sie nicht via FTP oder HTTP auf eine externe (auf einem anderen Server befindliche) Datei zuzugreifen.';
 $lang['test_remote_url'] = 'Test auf eine Remote-URL';
-$lang['test_remote_url_failed'] = 'Die Einstellungen Ihres Hosters erlauben nicht, eine Datei auf einem externen Webserver zu &ouml;ffnen. Aufgrund dessen erh&auml;lt Ihre CMSms-Installation von cmsmadesimple.org keine Informationen &uuml;ber neue Versionen.';
+$lang['test_remote_url_failed'] = 'Die Einstellungen Ihres Hosters erlauben nicht, eine Datei auf einem externen Webserver zu &ouml;ffnen. Aufgrund dessen erh&auml;lt Ihre CMSMS-Installation von cmsmadesimple.org keine Informationen &uuml;ber neue Versionen.';
 $lang['connection_error'] = 'Auf Ihrem Host sind keine ausgehenden http-Verbindungen erlaubt! Verwenden Sie eine Firewall oder Zugriffskontrolllisten f&uuml;r externe Verbindungen? Dies hat zur Folge, dass Sie den ModulManager und m&ouml;glicherweise weitere Funktionalit&auml;ten nicht nutzen k&ouml;nnen.';
 $lang['remote_connection_timeout'] = 'Keine Verbindung wegen Zeit&uuml;berschreitung!';
 $lang['search_string_find'] = 'Verbindung ok!';
@@ -262,7 +273,7 @@ $lang['remote_response_ok'] = 'Antwort des CMSms-Remote-Servers: ok!';
 $lang['remote_response_404'] = 'Antwort des CMSms-Remote-Servers: Versionsdatei nicht gefunden!';
 $lang['remote_response_error'] = 'Antwort des CMSms-Remote-Servers: Fehler!';
 $lang['test_check_file_upload'] = 'Pr&uuml;fung der M&ouml;glichkeit zum Hochladen von Dateien';
-$lang['test_check_file_failed'] = 'Wenn diese Funktion deaktiviert ist, k&ouml;nnen Sie die in CMS made simple enthaltenen F&auml;higkeiten zum Hochladen von Dateien nicht nutzen. Falls m&ouml;glich sollte Ihr Systemadministrator diese Beschr&auml;nkung aufheben. Sie sollten jedoch wissen, was Sie tun.';
+$lang['test_check_file_failed'] = 'Wenn diese Funktion deaktiviert ist, k&ouml;nnen Sie die in CMS Made Simple enthaltenen F&auml;higkeiten zum Hochladen von Dateien nicht nutzen. Falls m&ouml;glich sollte Ihr Systemadministrator diese Beschr&auml;nkung aufheben. Sie sollten jedoch wissen, was Sie tun.';
 $lang['test_check_memory'] = 'Pr&uuml;fung des PHP-Speicher-Limits';
 $lang['test_check_memory_failed'] = 'M&ouml;glicherweise wird CMSms mit dem Ihnen zur Verf&uuml;gung stehenden Speicher nicht richtig funktionieren. Falls m&ouml;glich sollten Sie Ihren Systemadministrator bitten, diesen Wert zu erh&ouml;hen. Sie sollten jedoch wissen, was Sie tun.';
 $lang['test_check_time_limit'] = 'Pr&uuml;fung des PHP-Zeitlimits (Sekunden)';
@@ -272,18 +283,18 @@ $lang['test_check_post_max_failed'] = 'Es ist Ihnen nicht m&ouml;glich, (gr&ouml
 $lang['test_check_upload_max'] = 'Pr&uuml;fung der maximal hochladbaren Datei-Gr&ouml;&szlig;e';
 $lang['test_check_upload_max_failed'] = 'Es ist Ihnen nicht m&ouml;glich, (gr&ouml;&szlig;ere) Dateien &uuml;ber die integrierte Dateiverwaltung hochzuladen. Seien Sie sich dieser Einschr&auml;nkung bewusst.';
 $lang['test_check_writable'] = 'Pr&uuml;fung, ob %s beschreibbar ist';
-$lang['test_check_upload_failed'] = 'Das uploads-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen.';
-$lang['test_check_images_failed'] = 'Das Bilder-Verzeichnis (Standard: uploads/images) ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen und zu verwenden.';
-$lang['test_check_modules_failed'] = 'Das modules-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Module &uuml;ber die Administration zu hochzuladen.';
+$lang['test_check_upload_failed'] = 'Das /uploads-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen.';
+$lang['test_check_images_failed'] = 'Das Bilder-Verzeichnis (Standard: /uploads/images) ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen und zu verwenden.';
+$lang['test_check_modules_failed'] = 'Das /modules-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Module &uuml;ber die Administration zu hochzuladen.';
 $lang['test_check_file_get_contents'] = 'Pr&uuml;fung auf die Funktion file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Ihnen ist es nicht m&ouml;glich, irgend eine Funktionalit&auml;t zu verwenden, die diese Funktion ben&ouml;tigt.';
 $lang['test_check_session_save_path'] = 'Pr&uuml;fung, ob der Pfad session.save_path &uuml;berschreibbar ist';
-$lang['test_empty_session_save_path'] = 'session.save_path ist bei Ihnen leer. PHP wird jetzt den tempor&auml;ren Speicher des Betriebssystems verwenden. Sollten bei Ihnen SESSION-Probleme auftreten und die Funktion ini_set ausf&uuml;hrbar sein, k&ouml;nnten Sie versuchen, Session-Cookies zu aktivieren. F&uuml;gen Sie dazu als erste Zeile folgendes der include.php hinzu: ini_set(&#039;session.use_only_cookies&#039;, 1);';
+$lang['test_empty_session_save_path'] = 'session.save_path ist bei Ihnen leer. PHP wird jetzt den tempor&auml;ren Speicher des Betriebssystems verwenden. Sollten bei Ihnen SESSION-Probleme auftreten und die Funktion ini_set ausf&uuml;hrbar sein, k&ouml;nnten Sie versuchen, Session-Cookies zu aktivieren. F&uuml;gen Sie dazu als erste Zeile folgendes der config.php hinzu: <code>ini_set(&#039;session.use_only_cookies&#039;, 1);</code>';
 $lang['test_check_session_save_path_failed'] = 'Ihr System verwendet aktuell den Pfad &quot;%s&quot;. Wenn der Pfad nicht &uuml;berschreibbar ist, k&ouml;nnen Sie sich unter Umst&auml;nden nicht in der Administration anmelden. Bei eventuell auftretenden Problemen sollten Sie dies zun&auml;chst &uuml;berpr&uuml;fen. Dieser Test kann fehlschlagen, wenn der Safe-Modus aktiviert ist.';
 $lang['test_check_ini_set'] = 'Pr&uuml;fung, ob die Funktion ini_set() ausf&uuml;hrbar ist';
 $lang['test_check_ini_set_failed'] = 'Die M&ouml;glichkeit, Einstellungen der php.ini &uuml;berschreiben zu k&ouml;nnen, ist zwar nicht zwingend. Einige (optionale) Zusatzfunktionen verwenden jedoch ini_set(), um zum Beispiel Zeitlimits zu ver&auml;ndern oder das Hochladen von gr&ouml;&szlig;eren Dateien zu erlauben usw. Ohne diese F&auml;higkeit kann es zu Unterschieden in der Funktionsweise von Modulen kommen. Dieser Test kann fehlschlagen, wenn der Safe-Modus aktiviert ist.';
 $lang['install_admin_header'] = 'Informationen zum Administratoren-Konto';
-$lang['install_admin_info'] = 'Geben Sie hier den Benutzernamen, die Emailadresse und das Passwort f&uuml;r den Administrator ein und notieren sich diese Daten irgendwo, da Sie ohne diese Daten keinen Zugang zur Administration von CMS made simple erhalten.';
+$lang['install_admin_info'] = 'Geben Sie hier den Benutzernamen, die Emailadresse und das Passwort f&uuml;r den Administrator ein und notieren sich diese Daten irgendwo, da Sie ohne diese Daten keinen Zugang zur Administration von CMS Made Simple erhalten.';
 $lang['install_admin_email'] = 'Email-Adresse';
 $lang['install_admin_email_info'] = 'Konto-Daten per Email versenden';
 $lang['install_admin_email_note'] = '<strong>Hinweis:</strong> F&uuml;r den Emailversand wird die PHP-Funktion mail() verwendet. Wenn Sie diese Email nicht erhalten, kann das ein Hinweis darauf sein, dass Ihr Server nicht richtig konfiguriert ist. Kontaktieren Sie daf&uuml;r Ihren Hoster.';
@@ -305,11 +316,11 @@ $lang['install_admin_db_create'] = 'Tabellen erzeugen (ACHTUNG: bereits existier
 $lang['install_admin_db_prefix'] = 'Tabellen-Prefix';
 $lang['install_admin_db_sample'] = 'Musterdaten (Templates, Inhalte) installieren';
 $lang['retry'] = 'Wiederholen';
-$lang['install_admin_db_create_seq'] = 'Erstelle die sequentielle Tabelle %s ...';
-$lang['install_admin_importing'] = 'Importiere die Beispieldaten ...';
+$lang['install_admin_db_create_seq'] = 'Erstellung der sequentiellen Tabelle %s ...';
+$lang['install_admin_importing'] = 'Import der Beispieldaten ...';
 $lang['invalid_query'] = 'Ung&uuml;ltige Abfrage: %s';
-$lang['install_creating_table'] = '<p>Erstelle die Tabelle %s ... [%s]</p>';
-$lang['install_creating_index'] = '<p>Erzeuge Index in der Tabelle %s ... [%s]</p>';
+$lang['install_creating_table'] = '<p>Erstellung der Tabelle %s ... [%s]</p>';
+$lang['install_creating_index'] = '<p>Erstellung des Index in der Tabelle %s ... [%s]</p>';
 $lang['done'] = 'erledigt';
 $lang['failed'] = 'fehlgeschlagen';
 $lang['install_admin_error_schema'] = 'Fehler im SQL-Schema';
@@ -319,7 +330,7 @@ $lang['install_admin_setup'] = 'Nun geht&#039;s weiter mit den Einstellungen der
 $lang['install_admin_docroot'] = 'CMS Dokumenten-Root (vom Webserver aus gesehen)';
 $lang['install_admin_docroot_path'] = 'Pfad zum Dokumenten-Root';
 $lang['install_admin_querystring'] = 'Abfrage-/Query-String (Wenn keine Probleme auftreten, k&ouml;nnen Sie den Wert unver&auml;ndert lassen. Die Datei config.php kann sp&auml;ter manuell anpasst werden.';
-$lang['invalid_querys'] = '<b>WARNUNG<b/>: Ung&uuml;ltige Abfragen auf Ihre Datenbank!';
+$lang['invalid_querys'] = '<strong>WARNUNG</strong>: Ung&uuml;ltige Abfragen auf Ihre Datenbank!';
 $lang['install_admin_sitedown'] = 'Fehler: Die Datei /tmp/cache/SITEDOWN konnte nicht entfernt werden. Bitte l&ouml;schen Sie diese manuell.';
 $lang['install_admin_update_hierarchy'] = 'Die Seitenhierarchie wird aktualisiert ... ';
 $lang['install_admin_set_core_event'] = 'Die Core-Ereignisse werden erstellt ... ';
@@ -331,16 +342,15 @@ $lang['install_admin_congratulations'] = 'Gratulation, die Installation ist voll
 $lang['could_not_connect_db'] = 'Die Verbindung zur Datenbank konnte nicht hergestellt werden. Pr&uuml;fen Sie, ob der Benutzername, das Passwort sowie der Name und die Host-Adresse der Datenbank richtig sind und ob dieser Benutzer Zugriff auf die angegebene Datenbank hat.';
 $lang['cannot_write_config'] = 'Fehler: Kann nicht in die Datei %s schreiben.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple - Informationen zum Administrator-Konto';
-$lang['email_accountinfo_message'] = 'Vielen Dank f&uuml;r die Installation von CMS made simple.
+$lang['email_accountinfo_message'] = 'Vielen Dank f&uuml;r die Installation von CMS Made Simple.
 
 Mit den folgenden Daten k&ouml;nnen Sie sich in der Administration anmelden:
 Benutzername: %s
 Passwort: %s
 
 In die Administration Ihrer Seite gelangen Sie hier: %s';
-$lang['qca'] = 'P0-75091478-1268421814072';
-$lang['utma'] = '156861353.728989452.1268567475.1270807906.1270924085.6';
+$lang['utma'] = '156861353.1543459933.1310675457.1310675457.1310675457.1';
+$lang['utmz'] = '156861353.1310675457.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1270924085.6.4.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
