@@ -1,4 +1,8 @@
 <?php
+$lang['setup_flat_urls'] = 'Gli URL abbreviati sono impostati';
+$lang['install_timezone'] = 'Alcuni server che eseguono php 5.3 hanno un fuso orario impostato non correttamente.  Selezionate il fuso orario appropriato dalla lista precedente.  Se non &egrave; necessario nel vostro server, potete selezionare &quot;Nessuno&quot;, potete modificare questa impostazione nel file config.php anche in seguito.';
+$lang['timezone'] = 'Fuso Orario';
+$lang['none'] = 'Nessuno';
 $lang['test_error_estrict'] = 'Controllo error_reporting per accertare che E_STRICT sia disabilitato';
 $lang['test_estrict_failed'] = 'E_STRICT &egrave; abilitato';
 $lang['info_estrict_failed'] = 'Alcune librerie utilizzate da CMSMS non funzionano correttamente con E_STRICT.  Vi preghiamo di disabilitarlo prima di procedere';
@@ -59,7 +63,7 @@ $lang['is_readable_false'] = 'Questa risorsa non &egrave; leggibile!';
 $lang['checksum_match'] = 'I checksum coincidono!';
 $lang['checksum_not_match'] = 'I checksum non coincidono!';
 $lang['not_checksum'] = 'Non riesco a recuperare il checksum!';
-$lang['format_datetime'] = '%c';
+$lang['format_datetime'] = '%c ';
 $lang['upload_err_ini_size'] = 'Il file inviato supera il parametro upload_max_filesize in php.ini!';
 $lang['upload_err_form_size'] = 'Il file inviato supera il parametro MAX_FILE_SIZE specificato nel form HTML.';
 $lang['upload_err_partial'] = 'Il file inviato &egrave; stato caricato solo parzialmente.';
@@ -95,13 +99,13 @@ $lang['cms_site'] = 'Sito CMS';
 $lang['or_greater'] = 'O maggiore';
 $lang['sitename'] = 'Nome del sito';
 $lang['warning_safe_mode'] = '<strong><em>ATTENZIONE:</em></strong> PHP Safe mode &egrave; abilitato. Ci&ograve; provocher&agrave; difficolt&agrave; con i file caricati tramite l&#039;interfaccia del browser web, incluse immagini, modelli e pacchetti modulo in XML. E&#039; consigliabile contattare il vostro amministratore del sito per valutare la possibilit&agrave; di disattivare la modalit&agrave; safe mode.';
-$lang['test'] = 'Test';
+$lang['test'] = 'Test ';
 $lang['results'] = 'Risultati';
 $lang['untested'] = 'Non testato';
 $lang['owner'] = 'Proprietario';
 $lang['permissions'] = 'Permessi';
-$lang['off'] = 'Off';
-$lang['on'] = 'On';
+$lang['off'] = 'Off ';
+$lang['on'] = 'On ';
 $lang['permission_information'] = 'Informazioni sui permessi';
 $lang['server_os'] = 'Sistema Operativo del Server';
 $lang['server_api'] = 'API del server';
@@ -150,7 +154,7 @@ $lang['cancel'] = 'Annulla';
 $lang['cantchmodfiles'] = 'Non riesco a modificare i permessi su alcuni file';
 $lang['cantremovefiles'] = 'Problema nel rimuovere file (permessi?)';
 $lang['create'] = 'Crea';
-$lang['database'] = 'Database';
+$lang['database'] = 'Database ';
 $lang['databaseprefix'] = 'Prefisso del database';
 $lang['databasetype'] = 'Tipo di database';
 $lang['date'] = 'Data';
@@ -174,7 +178,7 @@ $lang['help'] = 'Aiuto';
 $lang['language'] = 'Linguaggio';
 $lang['lastname'] = 'Cognome';
 $lang['name'] = 'Nome';
-$lang['password'] = 'Password';
+$lang['password'] = 'Password ';
 $lang['passwordagain'] = 'Password (di nuovo)';
 $lang['remove'] = 'Rimuovi';
 $lang['saveconfig'] = 'Salva il Config';
@@ -197,7 +201,7 @@ $lang['upgrade_system'] = 'Sistema di aggiornamento';
 $lang['upgrade_thanks'] = 'Grazie per avere aggiornato CMS Made Simple alla versione';
 $lang['install_please_read'] = 'Vi invitiamo a leggere la pagina sulle <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problematiche di Installazione</a> nella documentazione di CMS Made Simple Documentation Wiki.';
 $lang['install_checking'] = 'Controllo dei permessi e delle impostazioni PHP';
-$lang['install_test'] = 'Test';
+$lang['install_test'] = 'Test ';
 $lang['install_result'] = 'Risultato';
 $lang['install_required_settings'] = 'Impostazioni richieste';
 $lang['install_recommended_settings'] = 'Impostazioni raccomandate';
@@ -338,9 +342,9 @@ nome utente: %s
 password: %s
 
 Potete accedere all&#039;area di amministrazione da qui: %s';
-$lang['qca'] = 'P0-341425854-1271258489279';
-$lang['utma'] = '156861353.1785716972.1271258827.1272464498.1272484592.7';
-$lang['utmz'] = '156861353.1272484592.7.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.974349155.1299072468.1302003201.1303465107.4';
+$lang['qca'] = 'P0-1868709163-1302003200778';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272484592';
+$lang['utmz'] = '156861353.1303465107.4.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
