@@ -1,4 +1,19 @@
 <?php
+$lang['installed_module'] = 'Modul nain&scaron;talovan&yacute;';
+$lang['automatedtask_success'] = 'Automatizovan&eacute; &uacute;lohu prebehli &uacute;spe&scaron;ne';
+$lang['ip_addr'] = 'IP adresa';
+$lang['install_admin_pwsalt_note'] = 'Pokiaľ si vyberiete voľbu hashovania hesla do administr&aacute;cie, nebude možnosť sp&auml;tne požiadať o reset hesla. ';
+$lang['admin_salt'] = 'Hashovan&eacute; heslo do administr&aacute;cie';
+$lang['setup_flat_urls'] = 'Nastavenie  priamych URL';
+$lang['install_timezone'] = 'Niektor&eacute; servery bežiace na php 5.3 maju sle nastaven&eacute; časov&eacute; p&aacute;smo .  Prośim vyberte časov&uacute; z&oacute;nu zo zoznamu niž&scaron;ie.  Ak nechcete vyberať, vyberte voľbu &quot;Žiadne&quot;';
+$lang['timezone'] = 'Časov&aacute; z&oacute;na';
+$lang['none'] = 'Žiadne';
+$lang['test_error_estrict'] = 'Test  error_reporting a vypnutie E_STRICT';
+$lang['test_estrict_failed'] = 'E_STRICT je zapnut&yacute;';
+$lang['info_estrict_failed'] = 'Niektor&eacute; knižnice CMSMS nebud&uacute; pracovať spr&aacute;vne s E_STRICT. Pros&iacute;m vypnute toto nastavenie pred pokračovan&iacute;m';
+$lang['test_error_edeprecated'] = 'Test  error_reporting a vypnutie E_DEPRECATED';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED je zapnut&yacute;';
+$lang['info_edeprecated_failed'] = 'Ak E_DEPRECATED je zapnut&eacute;, už&iacute;uvatelia uvidia veľa chybov&yacute;ch hl&aacute;sen&iacute;';
 $lang['invalidemail'] = 'E-mailov&aacute; adresa je nespr&aacute;vna';
 $lang['empty_query'] = 'Pr&aacute;zdny dotaz?? %s';
 $lang['no_db_driver'] = 'Neboli n&aacute;jdene  žiadne kompatibiln&eacute; ovl&aacute;dače pre datab&aacute;zu';
@@ -15,8 +30,8 @@ $lang['test_check_disable_functions'] = 'Kontrola vypnut&yacute;ch funkci&iacute
 $lang['test_check_disable_functions_failed'] = 'Varovanie: zoznam funkc&iacute; vypnut&yacute;ch na vačom serveri';
 $lang['install_admin_db_port'] = 'Port datab&aacute;zy';
 $lang['install_admin_db_port_info'] = 'V pr&iacute;pade že neviete, nechajte pr&aacute;zdne';
-$lang['install_admin_db_socket'] = 'Socket datab&acute;=azy';
-$lang['install_admin_db_socket_info'] = 'NEPODPOROVANĚ';
+$lang['install_admin_db_socket'] = 'Socket datab&aacute;zy';
+$lang['install_admin_db_socket_info'] = 'NEPODPOROVAN&Eacute;';
 $lang['install_admin_frontendlang'] = 'Prednastaven&yacute; jazyk pre web (frontend). Toto nastavuje spr&aacute;vanie pre prednastaven&eacute; hodnoty d&aacute;tumy a podobne.';
 $lang['install_default_encoding'] = 'Prednastaven&eacute; k&oacute;dovanie vo v&auml;č&scaron;ine pr&iacute;padov b&yacute;va utf-8.';
 $lang['installer_done'] = '[ok]';
@@ -53,7 +68,7 @@ $lang['is_readable_false'] = 'Tento zdroj nem&aacute; pr&aacute;va na č&iacute;
 $lang['checksum_match'] = 'Porovnanie kontroln&yacute;ch s&uacute;čtov!';
 $lang['checksum_not_match'] = 'Bez kontroly kontroln&yacute;ch s&uacute;čtov!';
 $lang['not_checksum'] = 'Neviem skontrolovať kontroln&eacute; s&uacute;čty!';
-$lang['format_datetime'] = '%c';
+$lang['format_datetime'] = '%c ';
 $lang['upload_err_ini_size'] = 'Nahr&aacute;van&yacute; s&uacute;bor je v&auml;č&scaron;&iacute; ako povolen&yacute; limit  v upload_max_filesize v php.ini!';
 $lang['upload_err_form_size'] = 'Nahr&aacute;van&yacute; s&uacute;bor je v&auml;č&scaron;&iacute; ako povolen&yacute; limit  v  MAX_FILE_SIZE, ktor&yacute; je zadan&yacute; v html vo formul&aacute;ri.';
 $lang['upload_err_partial'] = 'Nahr&aacute;van&yacute; s&uacute;bor bol nahran&yacute; len čiastočne.';
@@ -89,7 +104,7 @@ $lang['cms_site'] = 'CMS str&aacute;nka';
 $lang['or_greater'] = 'Alebo v&auml;č&scaron;&iacute;';
 $lang['sitename'] = 'N&aacute;zov str&aacute;nky';
 $lang['warning_safe_mode'] = '<strong><em>Varovanie:</em></strong> PHP Safe m&oacute;d zapnut&yacute;.  Toto m&ocirc;že sp&ocirc;sobiť probl&eacute;my pri nahr&aacute;van&iacute; s&uacute;borov cez administr&aacute;ciu (obrazky, s&uacute;bory, t&eacute;my, XML moduly) atď. Požiadajte svojho administr&aacute;tora o vypnutie tejto direktivy.';
-$lang['test'] = 'Test';
+$lang['test'] = 'Test ';
 $lang['results'] = 'V&yacute;sledky';
 $lang['untested'] = 'Netestovan&eacute;';
 $lang['owner'] = 'Vlastn&iacute;k';
@@ -180,7 +195,7 @@ $lang['unknown'] = 'Nezn&aacute;my';
 $lang['user'] = 'Už&iacute;vateľ';
 $lang['userdefinedtags'] = 'Použivateľsk&eacute; t&aacute;gy (UDT)';
 $lang['usermanagement'] = 'Spr&aacute;va použ&iacute;vateľov';
-$lang['username'] = 'Už&iacute;vateľks&eacute; meno';
+$lang['username'] = 'Už&iacute;vateľsk&eacute; meno';
 $lang['usernameincorrect'] = 'Už&iacute;vateľsk&eacute; meno alebo heslo nie s&uacute; spr&aacute;vne';
 $lang['version'] = 'Verzia';
 $lang['install_title'] = 'In&scaron;tal&aacute;cia syst&eacute;mu CMS Made Simple (step %s)';
@@ -191,7 +206,7 @@ $lang['upgrade_system'] = 'Update syst&eacute;mu';
 $lang['upgrade_thanks'] = 'Ďakujeme za aktualiz&aacute;ciu CMS Made simple na verziu';
 $lang['install_please_read'] = 'Pros&iacute;m, preč&iacute;tajte si <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">dokument&aacute;ciu k in&scaron;tal&aacute;cii</a> k CMS Made Simple.';
 $lang['install_checking'] = 'Kontrola pr&aacute;v a nastaven&iacute; PHP';
-$lang['install_test'] = 'Test';
+$lang['install_test'] = 'Test ';
 $lang['install_result'] = 'V&yacute;sledky';
 $lang['install_required_settings'] = 'Vyžadovan&eacute; nastavenia';
 $lang['install_recommended_settings'] = 'Doporučen&eacute; nastavenia';
@@ -244,8 +259,8 @@ $lang['test_may_not_exist'] = 'S&uacute;bor možno e&scaron;te neexistujte. Ak t
 $lang['could_not_retrieve_a_value'] = 'Nepodarilo sa z&iacute;skať hodnotu';
 $lang['displaying_the_value_originally'] = '<br />Zobrazovanie nastaven&iacute; z configuračn&eacute;ho s&uacute;boru (nemus&iacute; byť presn&eacute;)';
 $lang['test_check_xml_func'] = 'Kontrola z&aacute;kladne podpory pre XML (expat)';
-$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
-$lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
+$lang['test_check_xml_failed'] = 'Va&scaron;a in&scaron;tal&aacute;cia PHP neobsahuje podporu XML. M&ocirc;žete naďalej použ&iacute;vať syst&eacute;m, av&scaron;ak nebudete m&ocirc;cť využ&iacute;vať spr&aacute;vcu modulov pre in&scaron;tal&aacute;ciu a aktualiz&aacute;ciu modulov cez vzdialen&yacute; server.';
+$lang['test_allow_url_fopen_failed'] = 'Pokiaľ nastavenie allow url fopen je vypnut&eacute;, nebudete mať pr&iacute;stup k vzdialen&eacute;mu využitiu protokolov http alebo ftp.';
 $lang['test_remote_url'] = 'Test vzdialenej URL';
 $lang['test_remote_url_failed'] = 'Pravdepodobne nebude m&ocirc;žno otvoriť s&uacute;bor cez vzdialen&yacute; web server. ';
 $lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
@@ -256,9 +271,9 @@ $lang['remote_response_ok'] = 'Vzdialen&aacute; odpoveď: ok!';
 $lang['remote_response_404'] = 'Vzdialen&aacute; odpoved: nen&aacute;jedn&eacute;!';
 $lang['remote_response_error'] = 'Vzdialen&aacute; odpoveď: chyba!';
 $lang['test_check_file_upload'] = 'Kontroluje nahr&aacute;vanie s&uacute;borov';
-$lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
+$lang['test_check_file_failed'] = 'Pokiaľ je vypnut&aacute; voľba nahr&aacute;vania s&uacute;borov, nebudete m&ocirc;cť využ&iacute;vať žiadnu z možnost&iacute; nahr&aacute;vania s&uacute;borov v CMSMS. Pokiaľ je možn&eacute;, kontaktujte administr&aacute;tora servera, aby V&aacute;m v&scaron;etky nastavenia ohľadom nahr&aacute;vania s&uacute;borov povolil.';
 $lang['test_check_memory'] = 'Kontrolujem PHP limit pam&auml;te';
-$lang['test_check_memory_failed'] = 'You may not have enough memory to run CMSMS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.';
+$lang['test_check_memory_failed'] = 'Pravdepodobne nebudete mať dostatok pam&auml;ti na to, aby CMSMS s nain&scaron;talovan&yacute;mi modulmi fungoval spr&aacute;vne. Ak je to možn&eacute; sk&uacute;ste kontaktovať spr&aacute;vcu servera, aby V&aacute;m nav&yacute;&scaron;il t&uacute;to hodnotu. ';
 $lang['test_check_time_limit'] = 'Kontrolujem PHP časov&yacute; limit';
 $lang['test_check_time_limit_failed'] = 'Počet sek&uacute;nd pre beh skriptu. Pokiaľ skript presiahne t&uacute;to hodnotu zobraz&iacute; sa chybov&eacute; hl&aacute;senie';
 $lang['test_check_post_max'] = 'Kontrola max post size';
@@ -321,7 +336,7 @@ $lang['install_admin_install_modules'] = 'In&scaron;talujem moduly...';
 $lang['install_admin_index_search'] = 'Indexujem pre vyhľad&aacute;vac&iacute; modul...';
 $lang['install_admin_clear_cache'] = 'Premaz&aacute;vam ke&scaron; str&aacute;nok (ak existuje)...';
 $lang['install_admin_emailing'] = 'Odosielam inform&aacute;cie o novom konte e-mailom...';
-$lang['install_admin_congratulations'] = 'Gratulujeme, v&scaron;etko se nain&scaron;talovan=e - tu je va&scaron;e';
+$lang['install_admin_congratulations'] = 'Gratulujeme, in&scaron;tal&aacute;cia prebehla v poriadku - na tomto mieste n&aacute;jdete';
 $lang['could_not_connect_db'] = 'Nepodarilo sa pripojiť k datab&aacute;zi. Skontrolujte pros&iacute;m pr&iacute;stupov&eacute; meno a heslo do datab&aacute;zy, a jeho opr&aacute;vnenia.';
 $lang['cannot_write_config'] = 'Chyba: Nem&ocirc;žem zapisovať do %s.';
 $lang['email_accountinfo_subject'] = 'Inform&aacute;cie o vytvorenom pr&iacute;stupe pre CMS Made Simple';
@@ -332,9 +347,8 @@ už&iacute;vateľsk&eacute; meno: %s
 heslo: %s
 
 Prihl&aacute;ste sa pre administr&aacute;ciu str&aacute;nky: %s';
-$lang['utma'] = '156861353.1262346118.1255805318.1257599213.1257604175.18';
-$lang['utmz'] = '156861353.1257604175.18.17.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['qca'] = 'P0-1154349044-1255805318049';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1257604175';
+$lang['utma'] = '156861353.397069566.1316370484.1316370484.1316453841.2';
+$lang['utmz'] = '156861353.1316453841.2.2.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
