@@ -1,4 +1,21 @@
 <?php
+$lang['installed_module'] = 'Modulen installerad';
+$lang['automatedtask_success'] = 'Automatisk uppgift lyckades';
+$lang['ip_addr'] = 'IP Adress';
+$lang['install_admin_pwsalt_note'] = 'Om du v&auml;ljer att anv&auml;nda saltade l&ouml;senord s&aring; finns det ingen m&ouml;jlighet att &aring;terst&auml;lla administrat&ouml;rsl&ouml;senord f&ouml;rutom via gl&ouml;mt-l&ouml;senords-funktionen. Det &auml;r d&auml;rf&ouml;r n&ouml;dv&auml;ndigt att du anger en epost-adress till varje administrat&ouml;rskonto.';
+$lang['admin_salt'] = 'Anv&auml;nd saltade administrat&ouml;rsl&ouml;senord';
+$lang['setup_flat_urls'] = 'Flat URLs &auml;r aktiverat';
+$lang['install_timezone'] = 'Vissa servrar som k&ouml;r med PHP 5.3 har inte r&auml;tt tidszon inst&auml;lld. V&auml;lj r&auml;tt tidszon i listan nedan. Om detta inte &auml;r n&ouml;dv&auml;ndigt p&aring; din server kan du v&auml;lja &quot;Ingen&quot; <strong>Observera:</strong> Detta &auml;r inte enbart en inst&auml;llning som ber&ouml;r visning av datum utan p&aring;verkar &auml;ven alla ber&auml;kningar som inneh&aring;ller datum. Det &auml;r d&auml;rf&ouml;r rekomenderat att ange din servers tidszon. Denna inst&auml;llning kan &auml;ndras efter installationen genom att redigera i config.php.';
+$lang['timezone'] = 'Tidszon';
+$lang['none'] = 'Ingen';
+$lang['test_error_estrict'] = 'Testar error_reporting f&ouml;r att kontrollera att E_STRICT &auml;r deaktiverat';
+$lang['test_estrict_failed'] = 'E_STRICT &auml;r aktiverat';
+$lang['info_estrict_failed'] = 'Vissa paket som CMSMS anv&auml;nder fungerar inte bra med E_STRICT. Var v&auml;nlig deaktivera detta innan du forts&auml;tter.';
+$lang['test_error_edeprecated'] = 'Testar error_reporting f&ouml;r att kontrollera att E_DEPRECATED &auml;r deaktiverat';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED &auml;r aktiverat';
+$lang['info_edeprecated_failed'] = 'Om E_DEPRECATED &auml;r aktiverat i din error reporting kommer anv&auml;ndare att se m&aring;nga varningsmeddelanden som kan p&aring;verka utseendet och funktionaliteten';
+$lang['invalidemail'] = 'Den angivna e-postadressen &auml;r ogiltig';
+$lang['empty_query'] = 'Empty query?? %s ';
 $lang['no_db_driver'] = 'Inga kompatibla databasdrivrutiner hittades';
 $lang['test_check_output_buffering'] = 'Kontrollerar ';
 $lang['test_check_output_buffering_failed'] = 'Outputbuffring &auml;r inaktiverat. Du kommer antagligen inte att kunna anv&auml;nda n&aring;gon av funktionerna som kr&auml;ver detta';
@@ -194,7 +211,7 @@ $lang['install_result'] = 'Resultat';
 $lang['install_required_settings'] = 'Obligatoriska inst&auml;llningar';
 $lang['install_recommended_settings'] = 'Rekommenderade inst&auml;llningar';
 $lang['install_you_have'] = 'Du har';
-$lang['install_legend'] = 'Legend';
+$lang['install_legend'] = 'Legend ';
 $lang['install_symbol'] = 'Symbol ';
 $lang['install_definition'] = 'Beskrivning';
 $lang['install_value_passed'] = 'Ett obligatoriskt test lyckades';
@@ -330,8 +347,9 @@ anv&auml;ndarnamn: %s
 l&ouml;senord: %s
 
 Logga in p&aring; adminsidorna: %s';
-$lang['utma'] = '156861353.224849059.1225009882.1234300347.1234342351.82';
-$lang['utmz'] = '156861353.1234296925.80.44.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-1088949386-1297632998614';
+$lang['utmz'] = '156861353.1313947469.1.1.utmccn=(organic)|utmcsr=google|utmctr=cmsms translation center|utmcmd=organic';
+$lang['utma'] = '156861353.301356295.1313947469.1313947469.1313950036.2';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
