@@ -1,7 +1,7 @@
 <?php
 #CMS - CMS Made Simple
-#(c)2004 by Ted Kulp (wishy@users.sf.net)
-#This project's homepage is: http://cmsmadesimple.sf.net
+#(c)2004-2010 by Ted Kulp (wishy@users.sf.net)
+#This project's homepage is: http://www.cmsmadesimple.org
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -16,29 +16,27 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 6101 2010-01-28 19:06:35Z calguy1000 $
+#$Id: misc.functions.php 7440 2011-09-25 17:27:01Z calguy1000 $
 
 /**
  * Misc functions
  *
  * @package CMS
  */
+
+
 /**
  * Redirects to relative URL on the current site
  *
  * @author http://www.edoceo.com/
  * @since 0.1
+ * @param string The url to redirect to
+ * @return void
  */
 function redirect($to, $noappend=false)
 {
      $_SERVER['PHP_SELF'] = null;
 
-    global $gCms;
-	if (isset($gCms))
-		$config =& $gCms->GetConfig();
-	else
-		$config = array();
-
     $schema = $_SERVER['SERVER_PORT'] == '443' ? 'https' : 'http';
     $host = strlen($_SERVER['HTTP_HOST'])?$_SERVER['HTTP_HOST']:$_SERVER['SERVER_NAME'];
 
@@ -75,25 +73,16 @@ function redirect($to, $noappend=false)
         $to = $schema."://".$host."/".$to;
     }
 
-    //If session trans-id is being used, and they is on yo website, add it.
-	/*
-    if (ini_get("session.use_trans_sid") != "0" && $noappend == false && strpos($to,$host) !== false)
-    {
-        if(strpos($to,'?') !== false)//If there are no arguments start a querystring
-        {
-            //$to = $to."?".session_name()."=".session_id();
-        }
-        else//There are arguments, print an arg seperator
-        {
-            //$to = $to.ini_get('arg_separator.input').session_name()."=".session_id();
-        }
-    }
-	*/
-
     session_write_close();
 
+    $debug = false;
+    if( class_exists('CmsObject') )
+      {
+	$config = cmsms()->GetConfig();
+	$debug = $config['debug'];
+      }
 
-    if (headers_sent() && !(isset($config) && $config['debug'] == true))
+    if (headers_sent() && !$debug)
     {
         // use javascript instead
         echo '<script type="text/javascript">
@@ -109,7 +98,7 @@ function redirect($to, $noappend=false)
     }
     else
     {
-        if (isset($config['debug']) && $config['debug'] == true)
+        if ( $debug )
         {
             echo "Debug is on.  Redirecting disabled...  Please click this link to continue.<br />";
             echo "<a href=\"".$to."\">".$to."</a><br />";
@@ -119,7 +108,7 @@ function redirect($to, $noappend=false)
 			  {
 				echo "<div>".$sql_queries."</div>\n";
 			  }
-			foreach ($gCms->errors as $error)
+			foreach (cmsms()->get_errors() as $error)
 			{
 				echo $error;
 			}
@@ -137,13 +126,17 @@ function redirect($to, $noappend=false)
 
 /**
  * Given a page ID or an alias, redirect to it
+ * Retrieves the URL of the specified page, and performs a redirect
+ *
+ * @param mixed An integer page id or a string page alias.
+ * @return void
  */
 function redirect_to_alias($alias)
 {
-	global $gCms;
-	$manager =& $gCms->GetHierarchyManager();
-	$node =& $manager->sureGetNodeByAlias($alias);
-	$content =& $node->GetContent();
+  $gCms = cmsms();
+	$manager = $gCms->GetHierarchyManager();
+	$node = $manager->sureGetNodeByAlias($alias);
+	$content = $node->GetContent();
 	if (isset($content))
 	{
 		if ($content->GetURL() != '')
@@ -153,10 +146,14 @@ function redirect_to_alias($alias)
 	}
 }
 
+
 /**
- * Shows the difference in seconds between two microtime() values
+ * Calculate the difference in seconds between two microtime() values
  *
  * @since 0.3
+ * @param string Microtime value A
+ * @param string Microtime value B
+ * @return integer The difference.
  */
 function microtime_diff($a, $b) {
 	list($a_dec, $a_sec) = explode(" ", $a);
@@ -164,11 +161,15 @@ function microtime_diff($a, $b) {
 	return $b_sec - $a_sec + $b_dec - $a_dec;
 }
 
+
 /**
  * Joins a path together using proper directory separators
  * Taken from: http://www.php.net/manual/en/ref.dir.php
  *
+ * This method accepts a variable number of string arguments.
+ *
  * @since 0.14
+ * @return string
  */
 function cms_join_path()
 {
@@ -177,6 +178,19 @@ function cms_join_path()
 }
 
 
+/**
+ * Return the global gCms object
+ *
+ * @since 1.7
+ * @return object
+ */
+function &cmsms()
+{
+  if( class_exists('CmsObject') )
+    return CmsObject::get_instance();
+}
+
+
 /**
  * Shows a very close approximation of an Apache generated 404 error.
  *
@@ -185,6 +199,8 @@ function cms_join_path()
  * browser error pages (like what IE does) will be displayed.
  *
  * @since 0.3
+ * @deprecated
+ * @internal
  */
 #function ErrorHandler404($errno, $errmsg, $filename, $linenum, $vars)
 function ErrorHandler404()
@@ -208,7 +224,6 @@ function ErrorHandler404()
  * Simple template parser
  *
  * @since 0.6.1
- */
 
 	function parse_template ($template, $tpl_array, $warn=0)
 	{
@@ -249,7 +264,19 @@ function ErrorHandler404()
 		return $template;
 
 	}	// end parse_template();
+ */
 
+
+/**
+ * A method to perform HTML entity conversion on a string
+ *
+ * @see htmlentities
+ * @param string The input string
+ * @param string A flag indicating how quotes should be handled (see htmlentities) (ignored)
+ * @param string The input character set (ignored)
+ * @param boolean A flag indicating wether single quotes should be converted to entities.
+ * @return string the converted string.
+ */
 function cms_htmlentities($string, $param=ENT_QUOTES, $charset="UTF-8", $convert_single_quotes = false)
 {
 	$result = "";
@@ -258,12 +285,21 @@ function cms_htmlentities($string, $param=ENT_QUOTES, $charset="UTF-8", $convert
 	return $result;
 }
 
+
+/**
+ * @ignore
+ */
+define('CLEANED_FILENAME','BAD_FILE');
+
 /**
  * Clean up the filename, and ensure that the filename resides underneath
  * the cms_root directory, if it does not replace it with the hardcoded
  * string CLEANED_FILENAME
+ *
+ * @internal
+ * @param string The complete file specification
+ * @return string the cleaned file path.
  */
-define('CLEANED_FILENAME','BAD_FILE');
 function cms_cleanfile($filename)
 {
 	$realpath = realpath($filename);
@@ -273,8 +309,7 @@ function cms_cleanfile($filename)
 
 	// This ensures that the file specified is somewhere
 	// underneath the cms root path
-	global $gCms;
-	$config =& $gCms->GetConfig();
+	$config = cmsms()->GetConfig();
 	if( strpos($realpath, $config['root_path']) !== 0 ) {
 		return CLEANED_FILENAME;
 	}
@@ -284,35 +319,16 @@ function cms_cleanfile($filename)
 /**
  * Figures out the page name from the uri string.  Has to use different logic
  * based on the type of httpd server.
+ *
+ * @ignore
+ * @access private
+ * @return string
  */
 function cms_calculate_url()
 {
 	$result = '';
 
-    global $gCms;
-    $config =& $gCms->GetConfig();
-
-	//Apache
-	/*
-	if (isset($_SERVER["PHP_SELF"]) && !endswith($_SERVER['PHP_SELF'], 'index.php'))
-	{
-		$matches = array();
-
-		//Seems like PHP_SELF has whatever is after index.php in certain situations
-		if (strpos($_SERVER['PHP_SELF'], 'index.php') !== FALSE) {
-			if (preg_match('/.*index\.php\/(.*?)$/', $_SERVER['PHP_SELF'], $matches))
-			{
-				$result = $matches[1];
-			}
-		}
-		else
-		{
-			$result = $_SERVER['PHP_SELF'];
-		}
-	}
-	*/
-	//lighttpd
-	#else if (isset($_SERVER["REQUEST_URI"]) && !endswith($_SERVER['REQUEST_URI'], 'index.php'))
+	$config = cmsms()->GetConfig();
 
 	//apache and lighttpd
 	if (isset($_SERVER["REQUEST_URI"]) && !endswith($_SERVER['REQUEST_URI'], 'index.php'))
@@ -321,7 +337,11 @@ function cms_calculate_url()
 		if (preg_match('/.*index\.php\/(.*?)$/', $_SERVER['REQUEST_URI'], $matches))
 		{
 			$result = $matches[1];
-		}
+		}/*
+		else
+		{
+			$result = $_SERVER['PHP_SELF'];
+		}*/
 	}
 
 	//trim off the extension, if there is one set
@@ -335,16 +355,12 @@ function cms_calculate_url()
 }
 
 /**
- * Enter description here...
+ * A replacement for the built in htmlentities method.
  *
- * @param unknown $val
- * @param integer $quote_style
+ * @ignore
+ * @param string  input string
+ * @param boolean A flag wether or not to handle single quotes.
  * @return unknown
- *
- * $quote_style may be one of:
- *     ENT_COMPAT   : Will convert double-quotes and leave single-quotes alone.
- *     ENT_QUOTES   : Will convert both double and single quotes.
- *     ENT_NOQUOTES : Will leave both double and single quotes unconverted.
  */
 function my_htmlentities($val, $convert_single_quotes = false)
 {
@@ -403,10 +419,12 @@ function my_htmlentities($val, $convert_single_quotes = false)
 
 
 /**
- * Enter description here...
+ * A method to convert a string into UTF-8 entities
  *
- * @param unknown $val
- * @return unknown
+ * @internal
+ * @deprecated
+ * @param string Input string
+ * @return string
  */
 function cms_utf8entities($val)
 {
@@ -420,9 +438,6 @@ function cms_utf8entities($val)
 	// $val = str_replace( chr(0xCA), "", $val );
 
 	$val = str_replace( "&"            , "\u0026"         , $val );
-#	$val = str_replace( "<!--"         , "&#60;&#33;--"  , $val );
-#	$val = str_replace( "-->"          , "--&#62;"       , $val );
-#	$val = preg_replace( "/<script/i"  , "&#60;script"   , $val );
 	$val = str_replace( ">"            , "\u003E"          , $val );
 	$val = str_replace( "<"            , "\u003C"          , $val );
 
@@ -459,6 +474,7 @@ function cms_utf8entities($val)
 
 
 //Taken from http://www.webmasterworld.com/forum88/164.htm
+/*
 function nl2pnbr( $text )
 {
 	// Use \n for newline on all systems
@@ -474,8 +490,15 @@ function nl2pnbr( $text )
 	$text = preg_replace('|(?<!</p>)\s*\n|', "<br />", $text);
 
 	return $text;
-}
+}*/
 
+
+/**
+ * A function to put a backtrace into the generated log file.
+ * 
+ * @see debug_to_log, debug_bt
+ * @return void
+ */
 function debug_bt_to_log()
 {
     $bt=debug_backtrace();
@@ -488,7 +511,7 @@ function debug_bt_to_log()
     $bt = array_reverse($bt);
     foreach($bt as $trace)
     {
-      if( $elem['function'] == 'debug_bt_to_log' ) continue;
+      if( $trace['function'] == 'debug_bt_to_log' ) continue;
 
       $file = $trace['file'];
       $line = $trace['line'];
@@ -503,6 +526,11 @@ function debug_bt_to_log()
       }
 }
 
+/**
+ * A function to generate a backtrace in a readable format.
+ *
+ * @return void
+ */
 function debug_bt()
 {
     $bt=debug_backtrace();
@@ -537,7 +565,7 @@ function debug_bt()
 */
 function debug_display($var, $title="", $echo_to_screen = true, $use_html = true)
 {
-	global $gCms;
+  $gCms = cmsms();
 	$variables =& $gCms->variables;
 
 	$starttime = microtime();
@@ -555,12 +583,24 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
 
 	if (function_exists('memory_get_usage'))
 	{
-		$titleText .= ' - ('.memory_get_usage().')';
+	  $titleText .= ' - (usage: '.memory_get_usage().')';
 	}
 
+	$memory_peak = (function_exists('memory_get_peak_usage')?memory_get_peak_usage():'');
+	if( $memory_peak )
+	  {
+	    $titleText .= ' - (peak: '.$memory_peak.')';
+	  }
+
 	ob_start();
 	if ($use_html)
-		echo "<div><b>$titleText</b>\n";
+	  {
+	    echo "<div><b>$titleText</b>\n";
+	  }
+	else
+	  {
+	    echo "$titleText\n";
+	  }
 
 	if(FALSE == empty($var))
 	{
@@ -609,7 +649,7 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
 
 	if($echo_to_screen)
 	{
-		echo $output;
+	  echo $output;
 	}
 
 	return $output;
@@ -623,27 +663,38 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
  */
 function debug_output($var, $title="")
 {
-	global $gCms;
-	if($gCms->config["debug"] == true)
+  if(cmsms()->config["debug"] == true)
 	{
 		debug_display($var, $title, true);
 	}
 
 }
 
-function debug_to_log($var, $title='')
-{
-	global $gCms;
 
-	$errlines = explode("\n",debug_display($var, $title, false, false));
-	$filename = TMP_CACHE_LOCATION . '/debug.log';
-	//$filename = dirname(dirname(__FILE__)) . '/uploads/debug.log';
-	foreach ($errlines as $txt)
+/**
+ * Debug function to output debug information about a variable in a formatted matter
+ * to a debug file.
+ *
+ * @param mixed data to display
+ * @param string Optional title.
+ */
+function debug_to_log($var, $title='',$filename = '')
+{
+  if( cmsms()->config['debug_to_log'] || check_login(TRUE) )
+    {
+      if( $filename == '' )
 	{
-		error_log($txt . "\n", 3, $filename);
+	  $filename = TMP_CACHE_LOCATION . '/debug.log';
 	}
+      $errlines = explode("\n",debug_display($var, $title, false, false));
+      foreach ($errlines as $txt)
+	{
+	  error_log($txt . "\n", 3, $filename);
+	}
+    }
 }
 
+
 /**
  * Display $var nicely to the $gCms->errors array if $config['debug'] is set
  *
@@ -652,32 +703,28 @@ function debug_to_log($var, $title='')
  */
 function debug_buffer($var, $title="")
 {
-	global $gCms;
-	if ($gCms)
-	{
-		$config =& $gCms->GetConfig();
-
-		//debug_to_log($var, $title='');
-
-		if($config["debug"] == true)
-		{
-			$gCms->errors[] = debug_display($var, $title, false, true);
-		}
-	}
+  $config = cmsms()->GetConfig();
+  if($config["debug"] == true)
+    {
+      cmsms()->add_error(debug_display($var, $title, false, true));
+    }
 }
 
-function debug_sql($str, $newline)
-{
-	global $gCms;
-	if ($gCms)
-	{
-		$config =& $gCms->GetConfig();
 
-		if($config["debug"] == true)
-		{
-			$gCms->errors[] = debug_display($str, '', false, true);
-		}
-	}
+/**
+ * Debug an sql command
+ *
+ * @internal
+ * @param string SQL query
+ * @param boolean (unused)
+ */
+function debug_sql($str, $newline = false)
+{
+  $config = cmsms()->GetConfig();
+  if($config["debug"] == true)
+    {
+      cmsms()->add_error(debug_display($str, '', false, true));
+    }
 }
 
 /**
@@ -690,6 +737,7 @@ function debug_sql($str, $newline)
 * @param string $value
 * @param mixed $default_value (optional)
 * @param string $session_key (optional)
+* @deprecated
 * @return mixed
 */
 function get_request_value($value, $default_value = '', $session_key = '')
@@ -725,6 +773,7 @@ function get_request_value($value, $default_value = '', $session_key = '')
 *
 * @param string $value
 * @param mixed $default_value
+* @deprecated
 * @return mixed
 */
 function get_value_with_default($value, $default_value = '', $session_key = '')
@@ -775,6 +824,7 @@ function get_value_with_default($value, $default_value = '', $session_key = '')
 	return $return_value;
 }
 
+
 /**
  * Retrieve the $value from the $parameters array checking for
  * $parameters[$value] and $params[$id.$value]. Returns $default
@@ -857,6 +907,14 @@ function get_parameter_value($parameters, $value, $default_value = '', $session_
 	return $return_value;
 }
 
+/**
+ * A convenience function to create a dropdown control with supported encodings.
+ *
+ * @internal
+ * @param string A name for the control
+ * @param string The name of the option that should be selected.
+ * @return string
+ */
 function create_encoding_dropdown($name = 'encoding', $selected = '')
 {
 	$result = '';
@@ -879,10 +937,16 @@ function create_encoding_dropdown($name = 'encoding', $selected = '')
 }
 
 
+/**
+ * A method to remove a permission from the database.
+ *
+ * @internal
+ * @access private
+ * @param string The permission name
+ */
 function cms_mapi_remove_permission($permission_name)
 {
-  global $gCms;
-  $db =& $gCms->GetDB();
+  $db = cmsms()->GetDB();
 
   $query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name = ?";
   $row = &$db->GetRow($query, array($permission_name));
@@ -899,10 +963,19 @@ function cms_mapi_remove_permission($permission_name)
     }
 }
 
+
+/**
+ * A method to add a permission to the CMSMS permissions table
+ *
+ * @internal
+ * @access private
+ * @param unknown (ignored)
+ * @param string  The permission name
+ * @param string  The permission human readable text.
+ */
 function cms_mapi_create_permission($cms, $permission_name, $permission_text)
 {
-	global $gCms;
-	$db = &$gCms->GetDb();
+  $db = cmsms()->GetDb();
 
 	$query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name =" . $db->qstr($permission_name);
 	$result = $db->Execute($query);
@@ -923,6 +996,17 @@ function cms_mapi_create_permission($cms, $permission_name, $permission_text)
 }
 
 
+/**
+ * A function to test if a file specification matches an array of
+ * file specifications that indicate it should be excluded
+ *
+ * @internal
+ * @deprecated
+ * @access private
+ * @param string Flle specification
+ * @param array  Array of regular expressions.
+ * @return boolean
+ */
 function filespec_is_excluded( $file, $excludes )
 {
   // strip the path from the file
@@ -941,15 +1025,12 @@ function filespec_is_excluded( $file, $excludes )
 /**
  * Check the permissions of a directory recursively to make sure that
  * we have write permission to all files
- * &param  path      start path
-*/
+ *
+ * @param  string  Start directory.
+ * @return boolean
+ */
 function is_directory_writable( $path )
 {
-//   if( can_admin_upload() == FALSE )
-//     {
-//       return false;
-//     }
-
   if ( substr ( $path , strlen ( $path ) - 1 ) != '/' )
     {
       $path .= '/' ;
@@ -991,9 +1072,12 @@ function is_directory_writable( $path )
   return true;
 }
 
+
 /**
  * Return an array containing a list of files in a directory
  * performs a non recursive search
+ *
+ * @internal
  * @param path - path to search
  * @param extensions - include only files matching these extensions
  *                     case insensitive, comma delimited
@@ -1034,11 +1118,15 @@ function get_matching_files($dir,$extensions = '',$excludedot = true,$excludedir
 
 /**
  * Return an array containing a list of files in a directory
- * performs a recursive serach
- * @param  path      start path
- * @param  maxdepth  how deep to browse (-1=unlimited)
- * @param  mode      "FULL"|"DIRS"|"FILES"
+ * performs a recursive search
+ *
+ * @internal
+ * @param  string    Start Path.
+ * @param  array     Array of regular expressions indicating files to exclude.
+ * @param  int       How deep to browse (-1=unlimited)
+ * @param  string    "FULL"|"DIRS"|"FILES"
  * @param  d         for internal use only
+ * @return  array
 **/
 function get_recursive_file_list ( $path , $excludes, $maxdepth = -1 , $mode = "FULL" , $d = 0 )
 {
@@ -1067,6 +1155,13 @@ function get_recursive_file_list ( $path , $excludes, $maxdepth = -1 , $mode = "
 }
 
 
+/**
+ * A function to recursively delete all files and folders in a directory
+ * synonymous with rm -r
+ *
+ * @param string The directory name
+ * @return boolean
+ */
 function recursive_delete( $dirname )
 {
   // all subdirectories and contents:
@@ -1098,6 +1193,13 @@ function recursive_delete( $dirname )
 }
 
 
+/**
+ * A function to recursively chmod all files and folders in a directory
+ *
+ * @see chmod
+ * @param string The start location
+ * @param integer The mode
+ */
 function chmod_r( $path, $mode )
 {
   if( !is_dir( $path ) )
@@ -1132,33 +1234,83 @@ function chmod_r( $path, $mode )
   return @chmod( $path, $mode );
 }
 
-
+/**
+ * A method to serialize an object and encode it for storage or transport.
+ *
+ * @internal
+ * @param object The object to serialize
+ * @return string
+ */
 function SerializeObject(&$object)
 {
 	return base64_encode(serialize($object));
 }
 
+/**
+ * A function unserialize data into an object
+ *
+ * @internal
+ * @param string The serialized text.
+ * @return object  A valid object on success, or null
+ */
 function UnserializeObject(&$serialized)
 {
 	return  unserialize(base64_decode($serialized));
 }
 
+
+/**
+ * A convenience function to test wether one string starts with another
+ *
+ * i.e:  startswith('The Quick Brown Fox','The');
+ *
+ * @param string The string to test against
+ * @param string The search string
+ * @return boolean
+ */
 function startswith( $str, $sub )
 {
 	return ( substr( $str, 0, strlen( $sub ) ) == $sub );
 }
 
+/**
+ * Similar to the startswith method, this function tests with string A ends with string B
+ *
+ * i.e: endswith('The Quick Brown Fox','Fox');
+ *
+ * @param string The string to test against
+ * @param string The search string
+ * @return boolean
+ */
 function endswith( $str, $sub )
 {
 	return ( substr( $str, strlen( $str ) - strlen( $sub ) ) == $sub );
 }
 
+/**
+ * A convenience function to display the memory usage
+ *
+ * @internal
+ * @param string A prefix to display before the memory output
+ * @return void
+ */
 function showmem($string = '')
 {
 	var_dump($string . ' -- ' . memory_get_usage());
 }
 
-function munge_string_to_url($alias, $tolower = false)
+
+/**
+ * convert a human readable string into something that is suitable for use in URLS
+ * because many browsers don't support UTF-8 characters in URLS
+ *
+ * @internal
+ * @param string String to convert
+ * @param boolean indicates whether output string should be converted to lower case
+ * @param boolean indicates wether slashes should be allowed in the input.
+ * @return string
+ */
+function munge_string_to_url($alias, $tolower = false, $withslash = false)
 {
 	// replacement.php is encoded utf-8 and must be the first modification of alias
 	include(dirname(__FILE__) . '/replacement.php');
@@ -1170,13 +1322,19 @@ function munge_string_to_url($alias, $tolower = false)
 		$alias = strtolower($alias);
 	}
 
-	$alias = preg_replace('/[^a-z0-9-_]+/i','-',$alias);
+	$expr = '/[^a-z0-9-_]+/i';
+	if( $withslash )
+	  {
+	    $expr = '/[^a-z0-9-_\/]+/i';
+	  }
+	$alias = preg_replace($expr,'-',$alias);
 	//$alias = preg_replace("/[^\w-]+/", "-", $alias);
 	$alias = trim($alias, '-');
 
 	return $alias;
 }
 
+// I'm not gonna document these.
 if (!function_exists('file_put_contents')) {
     function file_put_contents($filename, $data) {
         $f = @fopen($filename, 'w');
@@ -1205,22 +1363,20 @@ if(!function_exists("file_get_contents"))
 }
 
 
-if(!function_exists("readfile"))
+function cms_readfile($filename)
 {
-    function readfile($filename)
-    {
-      @ob_start();
-      echo file_get_contents($filename);
-      $result = @ob_get_contents();
-      @ob_end_clean();
-      if( !empty($result) ) {
-	echo $result;
-        return TRUE;
-      }
-      return FALSE;
-    }
+  @ob_start();
+  echo file_get_contents($filename);
+  $result = @ob_get_contents();
+  @ob_end_clean();
+  if( !empty($result) ) {
+    echo $result;
+    return TRUE;
+  }
+  return FALSE;
 }
 
+
 // create the array_walk_recursive function in PHP4
 // from http://www.php.net/manual/en/function.array-walk-recursive.php
 if (!function_exists('array_walk_recursive'))
@@ -1276,6 +1432,10 @@ if (!function_exists("stripos")) {
  * Sanitize input to prevent against XSS and other nasty stuff.
  * Taken from cakephp (http://cakephp.org)
  * Licensed under the MIT License
+ * 
+ * @internal
+ * @param string input
+ * @return string
  */
 function cleanValue($val) {
 	if ($val == "") {
@@ -1305,6 +1465,10 @@ function cleanValue($val) {
  * Method to sanitize incoming html.
  * Take from cakephp (http://cakephp.org)
  * Licensed under the MIT License
+ *
+ * @param string Input HTML code.
+ * @param boolean Wether HTML tags should be removed.
+ * @return string
  */
 function cleanHtml($string, $remove = false) {
 	if ($remove) {
@@ -1318,17 +1482,25 @@ function cleanHtml($string, $remove = false) {
 }
 
 
-/**
- * Method to sanitize all entries in
- * a hash
- *
-*/
 define('CLEAN_INT','CLEAN_INT');
 define('CLEAN_FLOAT','CLEAN_FLOAT');
 define('CLEAN_NONE','CLEAN_NONE');
 define('CLEAN_STRING','CLEAN_STRING');
 define('CLEAN_REGEXP','regexp:');
 define('CLEAN_FILE','CLEAN_FILE');
+
+/**
+ * Method to sanitize all entries in a hash
+ * This method is called by the module api to clean incomming parameters in the frontend.
+ * It uses the map created with the SetParameterType() method in the module api.
+ *
+ * @internal
+ * @param string Module Name
+ * @param array  Hash data
+ * @param array  A map of param names and type information
+ * @param boolean A flag indicating wether unknown keys in the input data should be allowed.
+ * @param boolean A flag indicating wether keys should be treated as strings and cleaned.
+*/
 function cleanParamHash($modulename,$data,$map = false,
 			$allow_unknown = false,$clean_keys = true)
 {
@@ -1423,9 +1595,14 @@ function cleanParamHash($modulename,$data,$map = false,
   return $result;
 }
 
+
 /**
  * Returns all parameters sent that are destined for the module with
- * the given $id
+ * the given $id.  This method reads the parameters directly from the $_REQUEST
+ *
+ * @internal
+ * @param string ID (the module instance ID to use for extracting parameters)
+ * @return array
  */
 function GetModuleParameters($id)
 {
@@ -1451,6 +1628,13 @@ function GetModuleParameters($id)
 }
 
 
+/**
+ * A function to test if permissions are set correctly, and the server is set properly
+ * to allow users to upload to CMSMS.
+ *
+ * @internal
+ * @return boolean
+ */
 function can_users_upload()
 {
   # first, check to see if safe mode is enabled
@@ -1458,7 +1642,7 @@ function can_users_upload()
   # and the uploads and modules directory.  if they all match, then we
   # can upload files.
   # if safe mode is off, then we just have to check the permissions.
-  global $gCms;
+  $gCms = cmsms();
   $file_index = $gCms->config['root_path'].DIRECTORY_SEPARATOR.'index.php';
   $dir_uploads = $gCms->config['uploads_path'];
 
@@ -1495,6 +1679,14 @@ function can_users_upload()
   return TRUE;
 }
 
+
+/**
+ * A function to test if permissions, and php configuration is setup correctly
+ * to allow an administrator to upload files to CMSMS
+ *
+ * @internal
+ * @return boolean
+ */
 function can_admin_upload()
 {
   # first, check to see if safe mode is enabled
@@ -1502,7 +1694,7 @@ function can_admin_upload()
   # and the uploads and modules directory.  if they all match, then we
   # can upload files.
   # if safe mode is off, then we just have to check the permissions.
-  global $gCms;
+  $gCms = cmsms();
   $file_index = $gCms->config['root_path'].DIRECTORY_SEPARATOR.'index.php';
   $file_moduleinterface = $gCms->config['root_path'].DIRECTORY_SEPARATOR.
     $gCms->config['admin_dir'].DIRECTORY_SEPARATOR.'moduleinterface.php';
@@ -1552,6 +1744,15 @@ function can_admin_upload()
   return TRUE;
 }
 
+
+/** 
+ * A convenience function to interpret octal permissions, and return 
+ * a human readable string.  Uses the lang() function for translation.
+ *
+ * @internal
+ * @param int The permissions to test.
+ * @return string
+ */
 function interpret_permissions($perms)
 {
   $owner = array();
@@ -1600,6 +1801,13 @@ function interpret_permissions($perms)
   return array($owner,$group,$other);
 }
 
+
+/**
+ * A convenience function to return a boolean variable given a php ini key that represents a boolean
+ *
+ * @param string  The php ini key
+ * @return integer
+ */
 function ini_get_boolean($str)
 {
   $val1 = ini_get($str);
@@ -1611,20 +1819,40 @@ function ini_get_boolean($str)
   return $ret;
 }
 
+/**
+ * Another convenience function to output a human readable function stack trace
+ *
+ * @return void
+ */
 function stack_trace()
 {
   $stack = debug_backtrace();
   foreach( $stack as $elem )
     {
       if( $elem['function'] == 'stack_trace' ) continue;
-      echo $elem['file'].':'.$elem['line'].' - '.$elem['function'].'<br/>';
+      if( isset($elem['file'])  )
+	{
+	  echo $elem['file'].':'.$elem['line'].' - '.$elem['function'].'<br/>';
+	}
+      else
+	{
+	  echo ' - '.$elem['function'].'<br/>';
+	}
     }
 }
 
+
+/** 
+ * A wrapper around move_uploaded_file that attempts to ensure permissions on uploaded
+ * files are set correctly.
+ *
+ * @param string The temporary file specification
+ * @param string The destination file specification
+ * @return boolean.
+ */
 function cms_move_uploaded_file( $tmpfile, $destination )
 {
-   global $gCms;
-   $config =& $gCms->GetConfig();
+   $config = cmsms()->GetConfig();
 
    if( !@move_uploaded_file( $tmpfile, $destination ) )
    {
@@ -1635,6 +1863,15 @@ function cms_move_uploaded_file( $tmpfile, $destination )
    return true;
 }
 
+
+/**
+ * A function to read CSS cache information
+ *
+ * @deprecated
+ * @internal
+ * @param string Filename containing cash information
+ * @return array of css cache information
+ */
 function csscache_csvfile_to_hash($filename)
 {
   if( !is_readable($filename) ) return false;
@@ -1650,6 +1887,15 @@ function csscache_csvfile_to_hash($filename)
   return $result;
 }
 
+/**
+ * A function to take hash information representing CSS cache data and store it in a CSV file
+ *
+ * @deprecated
+ * @internal
+ * @param string Filename to output information to
+ * @param array  Hash of CSS cache information.
+ * @return void
+ */
 function csscache_hash_to_csvfile($filename,$hash)
 {
   $fh = @fopen($filename,'w');
@@ -1663,11 +1909,33 @@ function csscache_hash_to_csvfile($filename,$hash)
   fclose($fh);
 }
 
+/**
+ * A function to clear clear the cached CSS information
+ *
+ * @deprecated
+ * @internal
+ * @param string Filename containing CSS cache information
+ * @return void
+ */
 function css_cache_clear($filename)
 {
   @unlink($filename);
 }
 
+
+/**
+ * A function to test wether an IP address matches a list of expressions
+ * Credits to J.Adams <jna@retins.net>
+ *
+ * Expressions can be of the form
+ *   xxx.xxx.xxx.xxx        (exact)
+ *   xxx.xxx.xxx.[yyy-zzz]  (range)
+ *   xxx.xxx.xxx.xxx/nn    (nn = # bits, cisco style -- i.e. /24 = class C)
+ *
+ * @param string IP address to test
+ * @param array  Array of match expressions
+ * @return boolean
+ */
 function cms_ipmatches($ip,$checklist)
 {
   if( !function_exists('__testip') ) {
@@ -1687,7 +1955,8 @@ function cms_ipmatches($ip,$checklist)
     // Does not match:
     // xxx.xxx.xxx.xx[yyy-zzz]  (range, partial octets not supported)
 
-    if (ereg("([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)/([0-9]+)",$range,$regs)) {
+    $regs = array();
+    if (preg_match("/([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+)\/([0-9]+)/",$range,$regs)) {
       // perform a mask match
       $ipl = ip2long($ip);
       $rangel = ip2long($regs[1] . "." . $regs[2] . "." . $regs[3] . "." . $regs[4]);
@@ -1707,12 +1976,17 @@ function cms_ipmatches($ip,$checklist)
       }
     } else {
       // range based
-      $maskocts = split("\.",$range);
-      $ipocts = split("\.",$ip);
+      $maskocts = explode('.',$range);
+      $ipocts = explode('.',$ip);
+
+      if( count($maskocts) != count($ipocts) && count($maskocts) != 4 )
+	{
+	  return 0;
+	}
 
       // perform a range match
       for ($i=0; $i<4; $i++) {
-	if (ereg("\[([0-9]+)\-([0-9]+)\]",$maskocts[$i],$regs)) {
+	if (preg_match("/\[([0-9]+)\-([0-9]+)\]/",$maskocts[$i],$regs)) {
 	  if ( ($ipocts[$i] > $regs[2]) || ($ipocts[$i] < $regs[1])) {
 	    $result = 0;
 	  }
@@ -1740,16 +2014,16 @@ function cms_ipmatches($ip,$checklist)
   return FALSE;
 }
 
+
 /**
- * @package	isemail
  * @author	Dominic Sayers <dominic_sayers@hotmail.com>
  * @copyright	2009 Dominic Sayers
  * @license	http://www.opensource.org/licenses/cpal_1.0 Common Public Attribution License Version 1.0 (CPAL) license
  * @link	http://www.dominicsayers.com/isemail
  * @version	1.9 - Minor modifications to make it compatible with PHPLint
  * @return boolean
- * @var string  $email
- * @var boolean $checkDNS
+ * @param string  $email
+ * @param boolean $checkDNS
 */
 function is_email( $email, $checkDNS=false ) {
 	// Check that $email is a valid address. Read the following RFCs to understand the constraints:
@@ -2092,6 +2366,14 @@ function is_email( $email, $checkDNS=false ) {
 	return true;
 }
 
+
+/**
+ * A convenience method to output the secure param tag that is used on all admin links
+ *
+ * @internal
+ * @access private
+ * @return string
+ */
 function get_secure_param()
 {
   $urlext = '?';
@@ -2102,5 +2384,56 @@ function get_secure_param()
   $urlext .= CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
   return $urlext;
 }
+
+
+function cms_to_bool($str)
+{
+  if( is_numeric($str) )
+  {
+    return ((int)$str != 0)?TRUE:FALSE;
+  }
+
+  $str = strtolower($str);
+  if( $str == 'y' || $str == 'yes' || $str == 'true' ) return TRUE;
+  return FALSE;
+}
+
+
+function cms_get_jquery($exclude = '',$ssl = false,$cdn = false,$append = '',$custom_root='')
+{
+  $config = cms_config::get_instance();
+  $scripts = array();
+  $basePath=$custom_root!=''?trim($custom_root,'/'):($ssl?$config['ssl_url']:$config['root_url']);
+  
+  // Scripts to include
+  $scripts['jquery-1.6.2.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jquery/1.6.2/jquery.min.js':$basePath.'/lib/jquery/js/jquery-1.6.2.min.js').'"></script>'."\n";
+  $scripts['jquery-ui-1.8.14.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.14/jquery-ui.min.js':$basePath.'/lib/jquery/js/jquery-ui-1.8.14.min.js').'"></script>'."\n";
+  $scripts['jquery.ui.nestedSortable-1.3.4.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.ui.nestedSortable-1.3.4.js"></script>'."\n";
+  $scripts['jquery.json-2.2.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.json-2.2.js"></script>'."\n";
+  
+  // Check if we need exclude some script
+  if(!empty($exclude)) {
+    
+    $exclude_list = explode(",", trim(str_replace(' ','',$exclude)));
+    foreach($exclude_list as $one) {
+      
+      unset($scripts[$one]);
+    }		
+  }
+  // let them add scripts to the end ie: a jQuery plugin
+  if(!empty($append)) {
+    $append_list = explode(",", trim(str_replace(' ','',$append)));
+    foreach($append_list as $key => $item) {
+      $scripts['user_'+$key]='<script type="text/javascript" src="'.($item).'"></script>'."\n";;
+    }		
+  }
+  // Output
+
+  $output = '';
+  foreach($scripts as $script) {
+    $output .= $script;		
+  }
+  return $output;
+}
 # vim:ts=4 sw=4 noet
 ?>
