@@ -1,7 +1,7 @@
 <?php
 #CMS - CMS Made Simple
-#(c)2004 by Ted Kulp (wishy@users.sf.net)
-#This project's homepage is: http://cmsmadesimple.sf.net
+#(c)2004-2010 by Ted Kulp (wishy@users.sf.net)
+#This project's homepage is: http://www.cmsmadesimple.org
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: module.functions.php 6239 2010-04-19 23:14:37Z calguy1000 $
+#$Id: module.functions.php 7396 2011-09-15 12:57:25Z rolf1 $
 
 /**
  * Extend smarty for moduleinterface.php
@@ -24,32 +24,23 @@
  * @package CMS
  */
 
-/* a duplicate function?
-function cms_mapi_create_permission($cms, $permission_name, $permission_text) {
-
-	$db =& $cms->db;
-
-	$query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name =" . $db->qstr($permission_name); 
-	$result = $db->Execute($query);
-
-	if ($result && $result->RecordCount() < 1) {
-
-		$new_id = $db->GenID(cms_db_prefix()."permissions_seq");
-		$query = "INSERT INTO ".cms_db_prefix()."permissions (permission_id, permission_name, permission_text, create_date, modified_date) VALUES ($new_id, ".$db->qstr($permission_name).",".$db->qstr($permission_text).",".$db->DBTimeStamp(time()).",".$db->DBTimeStamp(time()).")";
-		$db->Execute($query);
-	}
-}
-*/
 
+/**
+ * A function to call a module as a smarty plugin
+ * This method is used by the {cms_module} plugin, and internally when {ModuleName} is called
+ *
+ * @internal
+ * @access private
+ * @param array A hash of parameters 
+ * @param object The smarty object
+ * @return string The module output
+ */
 function cms_module_plugin($params,&$smarty)
 {
-	global $gCms;
-	$cmsmodules = &$gCms->modules;
-
-	//$id = 'm' . ++$gCms->variables["modulenum"];
-	if( !isset($gCms->variables['mid_cache']) )
+	$mid_cache = cms_utils::get_app_data('mid_cache');
+	if( empty($mid_cache) )
 	  {
-	    $gCms->variables['mid_cache'] = array();
+	    $mid_cache = array();
 	  }
 	for( $i = 0; $i < 10; $i++ )
 	{
@@ -57,19 +48,21 @@ function cms_module_plugin($params,&$smarty)
 	  foreach($params as $key=>$value)
 	    $tmp .= $key.'='.$value;
 	  $id = 'm'.substr(md5($tmp),0,5);
-	  if( !isset($gCms->variables['mid_cache'][$id]) )
+	  if( !isset($mid_cache[$id]) )
 	    {
-	      $gCms->variables['mid_cache'][$id] = $id;
+	      $mid_cache[$id] = $id;
 	      break;
 	    }
 	}
+	cms_utils::set_app_data('mid_cache',$mid_cache);
 
 	$returnid = '';
-	if (isset($gCms->variables['pageinfo']) && isset($gCms->variables['pageinfo']->content_id))
+	$content_obj = cmsms()->get_variable('content_obj');
+	if (isset($content_obj) && $content_obj->Id())
 	  {
-	    $returnid = $gCms->variables['pageinfo']->content_id;
+	    $returnid = $content_obj->Id();
 	  }
-	$params = array_merge($params, GetModuleParameters($id));
+	//$params = array_merge($params, GetModuleParameters($id));
 
 	$modulename = '';
 	$action = 'default';
@@ -114,57 +107,37 @@ function cms_module_plugin($params,&$smarty)
 		  // and we're inline (the results are supposed to replace
 		  // the tag, not {content}
 		  $action = $mactaction;
+	      $params = array_merge($params, GetModuleParameters($id));
 		}
 	    }
 	}
 
 	if( $action == '' ) $action = 'default'; // probably not needed, but safe
 
-	if (isset($cmsmodules))
+	class_exists($modulename);
+	$module = cms_utils::get_module($modulename);
+	if( $module && $module->isPluginModule() )
 	{
-		$modulename = $params['module'];
-
-		foreach ($cmsmodules as $key=>$value)
-		{
-		  if (!strcasecmp($modulename,$key))
-		    {
-		      $modulename = $key;
-		    }
-		}
-
-		if (isset($modulename))
-		{
-			if (isset($cmsmodules[$modulename]))
-			{
-				if (isset($cmsmodules[$modulename]['object'])
-					&& $cmsmodules[$modulename]['installed'] == true
-					&& $cmsmodules[$modulename]['active'] == true
-					&& $cmsmodules[$modulename]['object']->IsPluginModule())
-				{
-					@ob_start();
-
-					$result = $cmsmodules[$modulename]['object']->DoActionBase($action, $id, $params, $returnid);
-					if ($result !== FALSE)
-					{
-						echo $result;
-					}
-					$modresult = @ob_get_contents();
-					@ob_end_clean();
-
-					if( isset($params['assign']) )
-					  {
-					    $smarty->assign(trim($params['assign']),$modresult);
-					    return;
-					  }
-					return $modresult;
-
-				}
-				else
-				{
-					return "<!-- Not a tag module -->\n";
-				}
-			}
-		}
+	  @ob_start();
+	  $result = $module->DoActionBase($action, $id, $params, $returnid);
+	  if ($result !== FALSE)
+	    {
+	      echo $result;
+	    }
+	  $modresult = @ob_get_contents();
+	  @ob_end_clean();
+	  
+	  if( isset($params['assign']) )
+	    {
+	      $smarty->assign(trim($params['assign']),$modresult);
+	      return;
+	    }
+	  return $modresult;
+	  
+	}
+	else
+	{
+	  return "<!-- Not a tag module -->\n";
 	}
 }
 
