@@ -1,19 +1,35 @@
 <?php
-#NCleanGrey Theme - A theme for CMS Made Simple
-#(c)2008 by Author: Nuno Costa - nuno.mfcosta@sapo.pt  /  criacaoweb.net / http://dev.cmsmadesimple.org/users/nuno/
+#-------------------------------------------------------------------------
+# NCleanGrey Theme - An admin theme for CMS Made Simple
+# (c)2008 by Author: Nuno Costa - nuno.mfcosta@sapo.pt  /  criacaoweb.net / http://dev.cmsmadesimple.org/users/nuno/
+# 
+#-------------------------------------------------------------------------
+# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
+# This project's homepage is: http://www.cmsmadesimple.org
 #
-#This program is free software; you can redistribute it and/or modify
-#it under the terms of the GNU General Public License as published by
-#the Free Software Foundation; either version 2 of the License, or
-#(at your option) any later version.
+#-------------------------------------------------------------------------
 #
-#This program is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
-#You should have received a copy of the GNU General Public License
-#along with this program; if not, write to the Free Software
-#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# However, as a special exception to the GPL, this software is distributed
+# as an addon module to CMS Made Simple.  You may not use this software
+# in any Non GPL version of CMS Made simple, or in any version of CMS
+# Made simple that does not indicate clearly and obviously in its admin 
+# section that the site was built with CMS Made simple.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
+#
+#-------------------------------------------------------------------------
 
 class NCleanGreyTheme extends AdminTheme
 {
@@ -103,9 +119,6 @@ class NCleanGreyTheme extends AdminTheme
 		}
 		</style>
 		<![endif]-->
-		<!--[if lt IE 7]>
-		<link rel="stylesheet" type="text/css" href="themes/NCleanGrey/css/ie6.css" />
-		<![endif]-->
 		'."\n";
 	}
     /**
@@ -127,8 +140,8 @@ class NCleanGreyTheme extends AdminTheme
 	echo '<div id="ncleangrey-container">';
 	//LOGO
 	echo '<div id="logocontainer">
-	<img src="themes/NCleanGrey/images/layout/logoTM.png" alt="'. $this->cms->siteprefs['sitename'] .'" title="'. $this->cms->siteprefs['sitename'] .'" />
-	<div class="logotext">'.lang('adminpaneltitle').' - '. $this->cms->siteprefs['sitename'] .'<br />'.lang('welcome_user').': '.$this->cms->variables['username'];
+	<img src="themes/NCleanGrey/images/layout/logoTM.png" alt="'. get_site_preference('sitename') .'" title="'. get_site_preference('sitename') .'" />
+	<div class="logotext">'.lang('adminpaneltitle').' - '. get_site_preference('sitename') .'<br />'.lang('welcome_user').': '.$this->cms->variables['username'];
 	echo"</div>\n";
 	echo"</div>\n";
 	//MENU
@@ -209,7 +222,7 @@ class NCleanGreyTheme extends AdminTheme
 	echo '<div class="itemoverflow">';
 	echo '<h2>'.lang('bookmarks').'</h2>';
 	echo '<p><a href="listbookmarks.php'.$urlext.'">'.lang('managebookmarks').'</a></p>';
-	global $gCms;
+	$gCms = cmsms();
 	$bookops =& $gCms->GetBookmarkOperations();
 	$marks = array_reverse($bookops->LoadBookmarks($this->userid));
 	$marks = array_reverse($marks);
@@ -407,7 +420,7 @@ class NCleanGreyTheme extends AdminTheme
 
     function DisplaySectionPages($section)
     {
-      global $gCms;
+      $gCms = cmsms();
       if (count($this->menuItems) < 1)
 	{
 	  // menu should be initialized before this gets called.
@@ -428,7 +441,7 @@ class NCleanGreyTheme extends AdminTheme
 	  // separate system modules from the rest.
 	  if( preg_match( '/module=([^&]+)/', $thisItem['url'], $tmp) )
 	    {
-	      if( array_search( $tmp[1], $gCms->cmssystemmodules ) === FALSE && $firstmodule == true )
+	      if( !ModuleOperations::get_instance()->IsSystemModule($tmp[1]) && $firstmodule == true )
 		{
 		  echo "<hr width=\"90%\"/>";
 		  $firstmodule = false;
